@@ -352,7 +352,7 @@ class Utilities:
 		return self._core.io.query_bin_or_ascii_float_list(query)
 
 	def query_bin_or_ascii_float_list_with_opc(self, query: str, timeout: int = None) -> List[float]:
-		"""Sends a OPC-synced query and reads an list of floating-point numbers that can be returned in ASCII format or in binary format.
+		"""Sends a OPC-synced query and reads a list of floating-point numbers that can be returned in ASCII format or in binary format.
 		- For ASCII format, the list numbers are decoded as comma-separated values.
 		- For Binary Format, the numbers are decoded based on the property BinFloatFormat, usually float 32-bit (FORM REAL,32).
 		If you do not provide timeout, the method uses current opc_timeout."""
@@ -365,7 +365,7 @@ class Utilities:
 		return self._core.io.query_bin_or_ascii_int_list(query)
 
 	def query_bin_or_ascii_int_list_with_opc(self, query: str, timeout: int = None) -> List[int]:
-		"""Sends a OPC-synced query and reads an list of floating-point numbers that can be returned in ASCII format or in binary format.
+		"""Sends a OPC-synced query and reads a list of floating-point numbers that can be returned in ASCII format or in binary format.
 		- For ASCII format, the list numbers are decoded as comma-separated values.
 		- For Binary Format, the numbers are decoded based on the property BinFloatFormat, usually float 32-bit (FORM REAL,32).
 		If you do not provide timeout, the method uses current opc_timeout."""
@@ -430,3 +430,15 @@ class Utilities:
 	def clear_lock(self):
 		"""Clears the existing thread lock, making the current session thread-independent from others that might share the current thread lock."""
 		self._core.io.clear_lock()
+
+	def sync_from(self, source: 'Utilities') -> None:
+		"""Synchronises these Utils with the source."""
+		self.logger.sync_from(source.logger)
+		self.assign_lock(source.get_lock())
+		self.bin_float_numbers_format = source.bin_float_numbers_format
+		self.bin_int_numbers_format = source.bin_int_numbers_format
+		self.data_chunk_size = source.data_chunk_size
+		self.encoding = source.encoding
+		self.instrument_status_checking = source.instrument_status_checking
+		self.opc_query_after_write = source.opc_query_after_write
+		self.opc_timeout = source.opc_timeout
