@@ -3,7 +3,7 @@ from .........Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Rpoint:
+class RpointCls:
 	"""Rpoint commands group definition. 4 total commands, 3 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,30 +14,30 @@ class Rpoint:
 	def maximum(self):
 		"""maximum commands group. 1 Sub-classes, 0 commands."""
 		if not hasattr(self, '_maximum'):
-			from .Maximum import Maximum
-			self._maximum = Maximum(self._core, self._cmd_group)
+			from .Maximum import MaximumCls
+			self._maximum = MaximumCls(self._core, self._cmd_group)
 		return self._maximum
 
 	@property
 	def x(self):
 		"""x commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_x'):
-			from .X import X
-			self._x = X(self._core, self._cmd_group)
+			from .X import XCls
+			self._x = XCls(self._core, self._cmd_group)
 		return self._x
 
 	@property
 	def y(self):
 		"""y commands group. 1 Sub-classes, 1 commands."""
 		if not hasattr(self, '_y'):
-			from .Y import Y
-			self._y = Y(self._core, self._cmd_group)
+			from .Y import YCls
+			self._y = YCls(self._core, self._cmd_group)
 		return self._y
 
-	def clone(self) -> 'Rpoint':
+	def clone(self) -> 'RpointCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Rpoint(self._core, self._cmd_group.parent)
+		new_group = RpointCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
