@@ -3,7 +3,7 @@ from ..........Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Sdqp:
+class SdqpCls:
 	"""Sdqp commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Sdqp:
 	def average(self):
 		"""average commands group. 1 Sub-classes, 0 commands."""
 		if not hasattr(self, '_average'):
-			from .Average import Average
-			self._average = Average(self._core, self._cmd_group)
+			from .Average import AverageCls
+			self._average = AverageCls(self._core, self._cmd_group)
 		return self._average
 
-	def clone(self) -> 'Sdqp':
+	def clone(self) -> 'SdqpCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Sdqp(self._core, self._cmd_group.parent)
+		new_group = SdqpCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
