@@ -3,7 +3,7 @@ from .........Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Gimbalance:
+class GimbalanceCls:
 	"""Gimbalance commands group definition. 2 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class Gimbalance:
 	def average(self):
 		"""average commands group. 1 Sub-classes, 0 commands."""
 		if not hasattr(self, '_average'):
-			from .Average import Average
-			self._average = Average(self._core, self._cmd_group)
+			from .Average import AverageCls
+			self._average = AverageCls(self._core, self._cmd_group)
 		return self._average
 
 	@property
 	def maximum(self):
 		"""maximum commands group. 1 Sub-classes, 0 commands."""
 		if not hasattr(self, '_maximum'):
-			from .Maximum import Maximum
-			self._maximum = Maximum(self._core, self._cmd_group)
+			from .Maximum import MaximumCls
+			self._maximum = MaximumCls(self._core, self._cmd_group)
 		return self._maximum
 
-	def clone(self) -> 'Gimbalance':
+	def clone(self) -> 'GimbalanceCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Gimbalance(self._core, self._cmd_group.parent)
+		new_group = GimbalanceCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
