@@ -3,7 +3,7 @@ from ......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Statistics:
+class StatisticsCls:
 	"""Statistics commands group definition. 2 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class Statistics:
 	def cumulativeDistribFnc(self):
 		"""cumulativeDistribFnc commands group. 1 Sub-classes, 0 commands."""
 		if not hasattr(self, '_cumulativeDistribFnc'):
-			from .CumulativeDistribFnc import CumulativeDistribFnc
-			self._cumulativeDistribFnc = CumulativeDistribFnc(self._core, self._cmd_group)
+			from .CumulativeDistribFnc import CumulativeDistribFncCls
+			self._cumulativeDistribFnc = CumulativeDistribFncCls(self._core, self._cmd_group)
 		return self._cumulativeDistribFnc
 
 	@property
 	def result(self):
 		"""result commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_result'):
-			from .Result import Result
-			self._result = Result(self._core, self._cmd_group)
+			from .Result import ResultCls
+			self._result = ResultCls(self._core, self._cmd_group)
 		return self._result
 
-	def clone(self) -> 'Statistics':
+	def clone(self) -> 'StatisticsCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Statistics(self._core, self._cmd_group.parent)
+		new_group = StatisticsCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
