@@ -3,7 +3,7 @@ from .........Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Compressed:
+class CompressedCls:
 	"""Compressed commands group definition. 3 total commands, 3 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,30 +14,30 @@ class Compressed:
 	def state(self):
 		"""state commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_state'):
-			from .State import State
-			self._state = State(self._core, self._cmd_group)
+			from .State import StateCls
+			self._state = StateCls(self._core, self._cmd_group)
 		return self._state
 
 	@property
 	def noRb(self):
 		"""noRb commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_noRb'):
-			from .NoRb import NoRb
-			self._noRb = NoRb(self._core, self._cmd_group)
+			from .NoRb import NoRbCls
+			self._noRb = NoRbCls(self._core, self._cmd_group)
 		return self._noRb
 
 	@property
 	def rbOffset(self):
 		"""rbOffset commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_rbOffset'):
-			from .RbOffset import RbOffset
-			self._rbOffset = RbOffset(self._core, self._cmd_group)
+			from .RbOffset import RbOffsetCls
+			self._rbOffset = RbOffsetCls(self._core, self._cmd_group)
 		return self._rbOffset
 
-	def clone(self) -> 'Compressed':
+	def clone(self) -> 'CompressedCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Compressed(self._core, self._cmd_group.parent)
+		new_group = CompressedCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
