@@ -3,7 +3,7 @@ from ..........Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Ai:
+class AiCls:
 	"""Ai commands group definition. 2 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class Ai:
 	def id(self):
 		"""id commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_id'):
-			from .Id import Id
-			self._id = Id(self._core, self._cmd_group)
+			from .Id import IdCls
+			self._id = IdCls(self._core, self._cmd_group)
 		return self._id
 
 	@property
 	def nmrl(self):
 		"""nmrl commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_nmrl'):
-			from .Nmrl import Nmrl
-			self._nmrl = Nmrl(self._core, self._cmd_group)
+			from .Nmrl import NmrlCls
+			self._nmrl = NmrlCls(self._core, self._cmd_group)
 		return self._nmrl
 
-	def clone(self) -> 'Ai':
+	def clone(self) -> 'AiCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Ai(self._core, self._cmd_group.parent)
+		new_group = AiCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
