@@ -3,7 +3,7 @@ from ...........Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Pmch:
+class PmchCls:
 	"""Pmch commands group definition. 2 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class Pmch:
 	def modulation(self):
 		"""modulation commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_modulation'):
-			from .Modulation import Modulation
-			self._modulation = Modulation(self._core, self._cmd_group)
+			from .Modulation import ModulationCls
+			self._modulation = ModulationCls(self._core, self._cmd_group)
 		return self._modulation
 
 	@property
 	def state(self):
 		"""state commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_state'):
-			from .State import State
-			self._state = State(self._core, self._cmd_group)
+			from .State import StateCls
+			self._state = StateCls(self._core, self._cmd_group)
 		return self._state
 
-	def clone(self) -> 'Pmch':
+	def clone(self) -> 'PmchCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Pmch(self._core, self._cmd_group.parent)
+		new_group = PmchCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
