@@ -3,7 +3,7 @@ from .........Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Pdsch:
+class PdschCls:
 	"""Pdsch commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Pdsch:
 	def pb(self):
 		"""pb commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_pb'):
-			from .Pb import Pb
-			self._pb = Pb(self._core, self._cmd_group)
+			from .Pb import PbCls
+			self._pb = PbCls(self._core, self._cmd_group)
 		return self._pb
 
-	def clone(self) -> 'Pdsch':
+	def clone(self) -> 'PdschCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Pdsch(self._core, self._cmd_group.parent)
+		new_group = PdschCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
