@@ -3,7 +3,7 @@ from .........Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Plci:
+class PlciCls:
 	"""Plci commands group definition. 3 total commands, 3 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,30 +14,30 @@ class Plci:
 	def cid(self):
 		"""cid commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_cid'):
-			from .Cid import Cid
-			self._cid = Cid(self._core, self._cmd_group)
+			from .Cid import CidCls
+			self._cid = CidCls(self._core, self._cmd_group)
 		return self._cid
 
 	@property
 	def cidGroup(self):
 		"""cidGroup commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_cidGroup'):
-			from .CidGroup import CidGroup
-			self._cidGroup = CidGroup(self._core, self._cmd_group)
+			from .CidGroup import CidGroupCls
+			self._cidGroup = CidGroupCls(self._core, self._cmd_group)
 		return self._cidGroup
 
 	@property
 	def plid(self):
 		"""plid commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_plid'):
-			from .Plid import Plid
-			self._plid = Plid(self._core, self._cmd_group)
+			from .Plid import PlidCls
+			self._plid = PlidCls(self._core, self._cmd_group)
 		return self._plid
 
-	def clone(self) -> 'Plci':
+	def clone(self) -> 'PlciCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Plci(self._core, self._cmd_group.parent)
+		new_group = PlciCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
