@@ -3,7 +3,7 @@ from ..........Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class CsWeight:
+class CsWeightCls:
 	"""CsWeight commands group definition. 5 total commands, 3 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,30 +14,30 @@ class CsWeight:
 	def state(self):
 		"""state commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_state'):
-			from .State import State
-			self._state = State(self._core, self._cmd_group)
+			from .State import StateCls
+			self._state = StateCls(self._core, self._cmd_group)
 		return self._state
 
 	@property
 	def fhFrame(self):
 		"""fhFrame commands group. 2 Sub-classes, 0 commands."""
 		if not hasattr(self, '_fhFrame'):
-			from .FhFrame import FhFrame
-			self._fhFrame = FhFrame(self._core, self._cmd_group)
+			from .FhFrame import FhFrameCls
+			self._fhFrame = FhFrameCls(self._core, self._cmd_group)
 		return self._fhFrame
 
 	@property
 	def shFrame(self):
 		"""shFrame commands group. 2 Sub-classes, 0 commands."""
 		if not hasattr(self, '_shFrame'):
-			from .ShFrame import ShFrame
-			self._shFrame = ShFrame(self._core, self._cmd_group)
+			from .ShFrame import ShFrameCls
+			self._shFrame = ShFrameCls(self._core, self._cmd_group)
 		return self._shFrame
 
-	def clone(self) -> 'CsWeight':
+	def clone(self) -> 'CsWeightCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = CsWeight(self._core, self._cmd_group.parent)
+		new_group = CsWeightCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
