@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Eutra:
+class EutraCls:
 	"""Eutra commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Eutra:
 	def frequency(self):
 		"""frequency commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_frequency'):
-			from .Frequency import Frequency
-			self._frequency = Frequency(self._core, self._cmd_group)
+			from .Frequency import FrequencyCls
+			self._frequency = FrequencyCls(self._core, self._cmd_group)
 		return self._frequency
 
-	def clone(self) -> 'Eutra':
+	def clone(self) -> 'EutraCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Eutra(self._core, self._cmd_group.parent)
+		new_group = EutraCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
