@@ -3,7 +3,7 @@ from ..........Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Fhop:
+class FhopCls:
 	"""Fhop commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Fhop:
 	def iihb(self):
 		"""iihb commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_iihb'):
-			from .Iihb import Iihb
-			self._iihb = Iihb(self._core, self._cmd_group)
+			from .Iihb import IihbCls
+			self._iihb = IihbCls(self._core, self._cmd_group)
 		return self._iihb
 
-	def clone(self) -> 'Fhop':
+	def clone(self) -> 'FhopCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Fhop(self._core, self._cmd_group.parent)
+		new_group = FhopCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
