@@ -3,7 +3,7 @@ from ...........Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Pusch:
+class PuschCls:
 	"""Pusch commands group definition. 2 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class Pusch:
 	def csField(self):
 		"""csField commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_csField'):
-			from .CsField import CsField
-			self._csField = CsField(self._core, self._cmd_group)
+			from .CsField import CsFieldCls
+			self._csField = CsFieldCls(self._core, self._cmd_group)
 		return self._csField
 
 	@property
 	def ndmrs(self):
 		"""ndmrs commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_ndmrs'):
-			from .Ndmrs import Ndmrs
-			self._ndmrs = Ndmrs(self._core, self._cmd_group)
+			from .Ndmrs import NdmrsCls
+			self._ndmrs = NdmrsCls(self._core, self._cmd_group)
 		return self._ndmrs
 
-	def clone(self) -> 'Pusch':
+	def clone(self) -> 'PuschCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Pusch(self._core, self._cmd_group.parent)
+		new_group = PuschCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
