@@ -3,7 +3,7 @@ from ......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class FePpm:
+class FePpmCls:
 	"""FePpm commands group definition. 3 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class FePpm:
 	def cc(self):
 		"""cc commands group. 3 Sub-classes, 0 commands."""
 		if not hasattr(self, '_cc'):
-			from .Cc import Cc
-			self._cc = Cc(self._core, self._cmd_group)
+			from .Cc import CcCls
+			self._cc = CcCls(self._core, self._cmd_group)
 		return self._cc
 
-	def clone(self) -> 'FePpm':
+	def clone(self) -> 'FePpmCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = FePpm(self._core, self._cmd_group.parent)
+		new_group = FePpmCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
