@@ -3,7 +3,7 @@ from ........Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Tmod:
+class TmodCls:
 	"""Tmod commands group definition. 2 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class Tmod:
 	def downlink(self):
 		"""downlink commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_downlink'):
-			from .Downlink import Downlink
-			self._downlink = Downlink(self._core, self._cmd_group)
+			from .Downlink import DownlinkCls
+			self._downlink = DownlinkCls(self._core, self._cmd_group)
 		return self._downlink
 
 	@property
 	def uplink(self):
 		"""uplink commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_uplink'):
-			from .Uplink import Uplink
-			self._uplink = Uplink(self._core, self._cmd_group)
+			from .Uplink import UplinkCls
+			self._uplink = UplinkCls(self._core, self._cmd_group)
 		return self._uplink
 
-	def clone(self) -> 'Tmod':
+	def clone(self) -> 'TmodCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Tmod(self._core, self._cmd_group.parent)
+		new_group = TmodCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
