@@ -3,7 +3,7 @@ from ......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Load:
+class LoadCls:
 	"""Load commands group definition. 7 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class Load:
 	def cc(self):
 		"""cc commands group. 2 Sub-classes, 0 commands."""
 		if not hasattr(self, '_cc'):
-			from .Cc import Cc
-			self._cc = Cc(self._core, self._cmd_group)
+			from .Cc import CcCls
+			self._cc = CcCls(self._core, self._cmd_group)
 		return self._cc
 
 	@property
 	def iq(self):
 		"""iq commands group. 2 Sub-classes, 0 commands."""
 		if not hasattr(self, '_iq'):
-			from .Iq import Iq
-			self._iq = Iq(self._core, self._cmd_group)
+			from .Iq import IqCls
+			self._iq = IqCls(self._core, self._cmd_group)
 		return self._iq
 
-	def clone(self) -> 'Load':
+	def clone(self) -> 'LoadCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Load(self._core, self._cmd_group.parent)
+		new_group = LoadCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
