@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Frame:
+class FrameCls:
 	"""Frame commands group definition. 5 total commands, 3 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,30 +14,30 @@ class Frame:
 	def count(self):
 		"""count commands group. 2 Sub-classes, 1 commands."""
 		if not hasattr(self, '_count'):
-			from .Count import Count
-			self._count = Count(self._core, self._cmd_group)
+			from .Count import CountCls
+			self._count = CountCls(self._core, self._cmd_group)
 		return self._count
 
 	@property
 	def scount(self):
 		"""scount commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_scount'):
-			from .Scount import Scount
-			self._scount = Scount(self._core, self._cmd_group)
+			from .Scount import ScountCls
+			self._scount = ScountCls(self._core, self._cmd_group)
 		return self._scount
 
 	@property
 	def ssubframe(self):
 		"""ssubframe commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_ssubframe'):
-			from .Ssubframe import Ssubframe
-			self._ssubframe = Ssubframe(self._core, self._cmd_group)
+			from .Ssubframe import SsubframeCls
+			self._ssubframe = SsubframeCls(self._core, self._cmd_group)
 		return self._ssubframe
 
-	def clone(self) -> 'Frame':
+	def clone(self) -> 'FrameCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Frame(self._core, self._cmd_group.parent)
+		new_group = FrameCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
