@@ -3,7 +3,7 @@ from ........Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class FormatPy:
+class FormatPyCls:
 	"""FormatPy commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class FormatPy:
 	def scd(self):
 		"""scd commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_scd'):
-			from .Scd import Scd
-			self._scd = Scd(self._core, self._cmd_group)
+			from .Scd import ScdCls
+			self._scd = ScdCls(self._core, self._cmd_group)
 		return self._scd
 
-	def clone(self) -> 'FormatPy':
+	def clone(self) -> 'FormatPyCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = FormatPy(self._core, self._cmd_group.parent)
+		new_group = FormatPyCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
