@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Uplink:
+class UplinkCls:
 	"""Uplink commands group definition. 16 total commands, 3 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,30 +14,30 @@ class Uplink:
 	def demod(self):
 		"""demod commands group. 13 Sub-classes, 0 commands."""
 		if not hasattr(self, '_demod'):
-			from .Demod import Demod
-			self._demod = Demod(self._core, self._cmd_group)
+			from .Demod import DemodCls
+			self._demod = DemodCls(self._core, self._cmd_group)
 		return self._demod
 
 	@property
 	def formatPy(self):
 		"""formatPy commands group. 1 Sub-classes, 0 commands."""
 		if not hasattr(self, '_formatPy'):
-			from .FormatPy import FormatPy
-			self._formatPy = FormatPy(self._core, self._cmd_group)
+			from .FormatPy import FormatPyCls
+			self._formatPy = FormatPyCls(self._core, self._cmd_group)
 		return self._formatPy
 
 	@property
 	def tracking(self):
 		"""tracking commands group. 2 Sub-classes, 0 commands."""
 		if not hasattr(self, '_tracking'):
-			from .Tracking import Tracking
-			self._tracking = Tracking(self._core, self._cmd_group)
+			from .Tracking import TrackingCls
+			self._tracking = TrackingCls(self._core, self._cmd_group)
 		return self._tracking
 
-	def clone(self) -> 'Uplink':
+	def clone(self) -> 'UplinkCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Uplink(self._core, self._cmd_group.parent)
+		new_group = UplinkCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
