@@ -3,7 +3,7 @@ from ........Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Chbs:
+class ChbsCls:
 	"""Chbs commands group definition. 2 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Chbs:
 	def amPower(self):
 		"""amPower commands group. 1 Sub-classes, 1 commands."""
 		if not hasattr(self, '_amPower'):
-			from .AmPower import AmPower
-			self._amPower = AmPower(self._core, self._cmd_group)
+			from .AmPower import AmPowerCls
+			self._amPower = AmPowerCls(self._core, self._cmd_group)
 		return self._amPower
 
-	def clone(self) -> 'Chbs':
+	def clone(self) -> 'ChbsCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Chbs(self._core, self._cmd_group.parent)
+		new_group = ChbsCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
