@@ -3,7 +3,7 @@ from ........Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Uplink:
+class UplinkCls:
 	"""Uplink commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Uplink:
 	def requirement(self):
 		"""requirement commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_requirement'):
-			from .Requirement import Requirement
-			self._requirement = Requirement(self._core, self._cmd_group)
+			from .Requirement import RequirementCls
+			self._requirement = RequirementCls(self._core, self._cmd_group)
 		return self._requirement
 
-	def clone(self) -> 'Uplink':
+	def clone(self) -> 'UplinkCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Uplink(self._core, self._cmd_group.parent)
+		new_group = UplinkCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
