@@ -3,7 +3,7 @@ from ........Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Continuous:
+class ContinuousCls:
 	"""Continuous commands group definition. 3 total commands, 3 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,30 +14,30 @@ class Continuous:
 	def pcount(self):
 		"""pcount commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_pcount'):
-			from .Pcount import Pcount
-			self._pcount = Pcount(self._core, self._cmd_group)
+			from .Pcount import PcountCls
+			self._pcount = PcountCls(self._core, self._cmd_group)
 		return self._pcount
 
 	@property
 	def plength(self):
 		"""plength commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_plength'):
-			from .Plength import Plength
-			self._plength = Plength(self._core, self._cmd_group)
+			from .Plength import PlengthCls
+			self._plength = PlengthCls(self._core, self._cmd_group)
 		return self._plength
 
 	@property
 	def state(self):
 		"""state commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_state'):
-			from .State import State
-			self._state = State(self._core, self._cmd_group)
+			from .State import StateCls
+			self._state = StateCls(self._core, self._cmd_group)
 		return self._state
 
-	def clone(self) -> 'Continuous':
+	def clone(self) -> 'ContinuousCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Continuous(self._core, self._cmd_group.parent)
+		new_group = ContinuousCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
