@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Power:
+class PowerCls:
 	"""Power commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Power:
 	def condition(self):
 		"""condition commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_condition'):
-			from .Condition import Condition
-			self._condition = Condition(self._core, self._cmd_group)
+			from .Condition import ConditionCls
+			self._condition = ConditionCls(self._core, self._cmd_group)
 		return self._condition
 
-	def clone(self) -> 'Power':
+	def clone(self) -> 'PowerCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Power(self._core, self._cmd_group.parent)
+		new_group = PowerCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
