@@ -3,7 +3,7 @@ from ......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Iq:
+class IqCls:
 	"""Iq commands group definition. 2 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class Iq:
 	def file(self):
 		"""file commands group. 1 Sub-classes, 0 commands."""
 		if not hasattr(self, '_file'):
-			from .File import File
-			self._file = File(self._core, self._cmd_group)
+			from .File import FileCls
+			self._file = FileCls(self._core, self._cmd_group)
 		return self._file
 
 	@property
 	def symbolRate(self):
 		"""symbolRate commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_symbolRate'):
-			from .SymbolRate import SymbolRate
-			self._symbolRate = SymbolRate(self._core, self._cmd_group)
+			from .SymbolRate import SymbolRateCls
+			self._symbolRate = SymbolRateCls(self._core, self._cmd_group)
 		return self._symbolRate
 
-	def clone(self) -> 'Iq':
+	def clone(self) -> 'IqCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Iq(self._core, self._cmd_group.parent)
+		new_group = IqCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
