@@ -3,7 +3,7 @@ from ......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Uwb:
+class UwbCls:
 	"""Uwb commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Uwb:
 	def measurement(self):
 		"""measurement commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_measurement'):
-			from .Measurement import Measurement
-			self._measurement = Measurement(self._core, self._cmd_group)
+			from .Measurement import MeasurementCls
+			self._measurement = MeasurementCls(self._core, self._cmd_group)
 		return self._measurement
 
-	def clone(self) -> 'Uwb':
+	def clone(self) -> 'UwbCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Uwb(self._core, self._cmd_group.parent)
+		new_group = UwbCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
