@@ -3,7 +3,7 @@ from .....Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Configure:
+class ConfigureCls:
 	"""Configure commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Configure:
 	def uwb(self):
 		"""uwb commands group. 1 Sub-classes, 0 commands."""
 		if not hasattr(self, '_uwb'):
-			from .Uwb import Uwb
-			self._uwb = Uwb(self._core, self._cmd_group)
+			from .Uwb import UwbCls
+			self._uwb = UwbCls(self._core, self._cmd_group)
 		return self._uwb
 
-	def clone(self) -> 'Configure':
+	def clone(self) -> 'ConfigureCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Configure(self._core, self._cmd_group.parent)
+		new_group = ConfigureCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
