@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Dump:
+class DumpCls:
 	"""Dump commands group definition. 2 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class Dump:
 	def capture(self):
 		"""capture commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_capture'):
-			from .Capture import Capture
-			self._capture = Capture(self._core, self._cmd_group)
+			from .Capture import CaptureCls
+			self._capture = CaptureCls(self._core, self._cmd_group)
 		return self._capture
 
 	@property
 	def inputPy(self):
 		"""inputPy commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_inputPy'):
-			from .InputPy import InputPy
-			self._inputPy = InputPy(self._core, self._cmd_group)
+			from .InputPy import InputPyCls
+			self._inputPy = InputPyCls(self._core, self._cmd_group)
 		return self._inputPy
 
-	def clone(self) -> 'Dump':
+	def clone(self) -> 'DumpCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Dump(self._core, self._cmd_group.parent)
+		new_group = DumpCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
