@@ -3,8 +3,8 @@ from ........Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Data:
-	"""Data commands group definition. 4 total commands, 2 Subgroups, 0 group commands"""
+class DataCls:
+	"""Data commands group definition. 6 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
 		self._core = core
@@ -14,22 +14,22 @@ class Data:
 	def length(self):
 		"""length commands group. 1 Sub-classes, 1 commands."""
 		if not hasattr(self, '_length'):
-			from .Length import Length
-			self._length = Length(self._core, self._cmd_group)
+			from .Length import LengthCls
+			self._length = LengthCls(self._core, self._cmd_group)
 		return self._length
 
 	@property
 	def rate(self):
-		"""rate commands group. 1 Sub-classes, 1 commands."""
+		"""rate commands group. 2 Sub-classes, 1 commands."""
 		if not hasattr(self, '_rate'):
-			from .Rate import Rate
-			self._rate = Rate(self._core, self._cmd_group)
+			from .Rate import RateCls
+			self._rate = RateCls(self._core, self._cmd_group)
 		return self._rate
 
-	def clone(self) -> 'Data':
+	def clone(self) -> 'DataCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Data(self._core, self._cmd_group.parent)
+		new_group = DataCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
