@@ -3,7 +3,7 @@ from ........Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Mac:
+class MacCls:
 	"""Mac commands group definition. 2 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Mac:
 	def fcs(self):
 		"""fcs commands group. 1 Sub-classes, 1 commands."""
 		if not hasattr(self, '_fcs'):
-			from .Fcs import Fcs
-			self._fcs = Fcs(self._core, self._cmd_group)
+			from .Fcs import FcsCls
+			self._fcs = FcsCls(self._core, self._cmd_group)
 		return self._fcs
 
-	def clone(self) -> 'Mac':
+	def clone(self) -> 'MacCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Mac(self._core, self._cmd_group.parent)
+		new_group = MacCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
