@@ -3,7 +3,7 @@ from ........Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Reserved:
+class ReservedCls:
 	"""Reserved commands group definition. 2 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Reserved:
 	def bit(self):
 		"""bit commands group. 1 Sub-classes, 1 commands."""
 		if not hasattr(self, '_bit'):
-			from .Bit import Bit
-			self._bit = Bit(self._core, self._cmd_group)
+			from .Bit import BitCls
+			self._bit = BitCls(self._core, self._cmd_group)
 		return self._bit
 
-	def clone(self) -> 'Reserved':
+	def clone(self) -> 'ReservedCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Reserved(self._core, self._cmd_group.parent)
+		new_group = ReservedCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
