@@ -5,7 +5,7 @@ from ......... import repcap
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Apackets:
+class ApacketsCls:
 	"""Apackets commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -15,9 +15,10 @@ class Apackets:
 	def get(self, window=repcap.Window.Default) -> str:
 		"""SCPI: FETCh<n>:PACKet:SYNC:DELTa:LENGth:APACkets \n
 		Snippet: value: str = driver.applications.k149Uwb.fetch.packet.sync.delta.length.apackets.get(window = repcap.Window.Default) \n
-		Returns whether the value of SFD is the same (IDEN) or not (MIX) for all packets. \n
+		Returns the payload of the packet in hexadecimal format. In accordance with IEEE 802.15.4, the LSB of each octet of the
+		payload is output first. \n
 			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fetch')
-			:return: result: Window"""
+			:return: result: Use n to select a 'Packet Insights' result display. Window"""
 		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
 		response = self._core.io.query_str(f'FETCh{window_cmd_val}:PACKet:SYNC:DELTa:LENGth:APACkets?')
 		return trim_str_response(response)
