@@ -3,8 +3,8 @@ from ........Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Sync:
-	"""Sync commands group definition. 2 total commands, 1 Subgroups, 0 group commands"""
+class SyncCls:
+	"""Sync commands group definition. 4 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
 		self._core = core
@@ -12,16 +12,16 @@ class Sync:
 
 	@property
 	def length(self):
-		"""length commands group. 1 Sub-classes, 1 commands."""
+		"""length commands group. 2 Sub-classes, 1 commands."""
 		if not hasattr(self, '_length'):
-			from .Length import Length
-			self._length = Length(self._core, self._cmd_group)
+			from .Length import LengthCls
+			self._length = LengthCls(self._core, self._cmd_group)
 		return self._length
 
-	def clone(self) -> 'Sync':
+	def clone(self) -> 'SyncCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Sync(self._core, self._cmd_group.parent)
+		new_group = SyncCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
