@@ -3,8 +3,8 @@ from ......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Packet:
-	"""Packet commands group definition. 32 total commands, 3 Subgroups, 0 group commands"""
+class PacketCls:
+	"""Packet commands group definition. 41 total commands, 4 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
 		self._core = core
@@ -14,30 +14,38 @@ class Packet:
 	def all(self):
 		"""all commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_all'):
-			from .All import All
-			self._all = All(self._core, self._cmd_group)
+			from .All import AllCls
+			self._all = AllCls(self._core, self._cmd_group)
 		return self._all
 
 	@property
 	def data(self):
 		"""data commands group. 10 Sub-classes, 0 commands."""
 		if not hasattr(self, '_data'):
-			from .Data import Data
-			self._data = Data(self._core, self._cmd_group)
+			from .Data import DataCls
+			self._data = DataCls(self._core, self._cmd_group)
 		return self._data
 
+	@property
+	def sts(self):
+		"""sts commands group. 1 Sub-classes, 0 commands."""
+		if not hasattr(self, '_sts'):
+			from .Sts import StsCls
+			self._sts = StsCls(self._core, self._cmd_group)
+		return self._sts
+
 	@property
 	def sync(self):
 		"""sync commands group. 4 Sub-classes, 0 commands."""
 		if not hasattr(self, '_sync'):
-			from .Sync import Sync
-			self._sync = Sync(self._core, self._cmd_group)
+			from .Sync import SyncCls
+			self._sync = SyncCls(self._core, self._cmd_group)
 		return self._sync
 
-	def clone(self) -> 'Packet':
+	def clone(self) -> 'PacketCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Packet(self._core, self._cmd_group.parent)
+		new_group = PacketCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
