@@ -3,7 +3,7 @@ from ........Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Psdu:
+class PsduCls:
 	"""Psdu commands group definition. 8 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class Psdu:
 	def level(self):
 		"""level commands group. 3 Sub-classes, 1 commands."""
 		if not hasattr(self, '_level'):
-			from .Level import Level
-			self._level = Level(self._core, self._cmd_group)
+			from .Level import LevelCls
+			self._level = LevelCls(self._core, self._cmd_group)
 		return self._level
 
 	@property
 	def nrmse(self):
 		"""nrmse commands group. 3 Sub-classes, 1 commands."""
 		if not hasattr(self, '_nrmse'):
-			from .Nrmse import Nrmse
-			self._nrmse = Nrmse(self._core, self._cmd_group)
+			from .Nrmse import NrmseCls
+			self._nrmse = NrmseCls(self._core, self._cmd_group)
 		return self._nrmse
 
-	def clone(self) -> 'Psdu':
+	def clone(self) -> 'PsduCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Psdu(self._core, self._cmd_group.parent)
+		new_group = PsduCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
