@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Frequency:
+class FrequencyCls:
 	"""Frequency commands group definition. 12 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class Frequency:
 	def chip(self):
 		"""chip commands group. 1 Sub-classes, 0 commands."""
 		if not hasattr(self, '_chip'):
-			from .Chip import Chip
-			self._chip = Chip(self._core, self._cmd_group)
+			from .Chip import ChipCls
+			self._chip = ChipCls(self._core, self._cmd_group)
 		return self._chip
 
 	@property
 	def offset(self):
 		"""offset commands group. 2 Sub-classes, 0 commands."""
 		if not hasattr(self, '_offset'):
-			from .Offset import Offset
-			self._offset = Offset(self._core, self._cmd_group)
+			from .Offset import OffsetCls
+			self._offset = OffsetCls(self._core, self._cmd_group)
 		return self._offset
 
-	def clone(self) -> 'Frequency':
+	def clone(self) -> 'FrequencyCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Frequency(self._core, self._cmd_group.parent)
+		new_group = FrequencyCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
