@@ -3,7 +3,7 @@ from ........Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Shr:
+class ShrCls:
 	"""Shr commands group definition. 8 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class Shr:
 	def mean(self):
 		"""mean commands group. 3 Sub-classes, 1 commands."""
 		if not hasattr(self, '_mean'):
-			from .Mean import Mean
-			self._mean = Mean(self._core, self._cmd_group)
+			from .Mean import MeanCls
+			self._mean = MeanCls(self._core, self._cmd_group)
 		return self._mean
 
 	@property
 	def peak(self):
 		"""peak commands group. 3 Sub-classes, 1 commands."""
 		if not hasattr(self, '_peak'):
-			from .Peak import Peak
-			self._peak = Peak(self._core, self._cmd_group)
+			from .Peak import PeakCls
+			self._peak = PeakCls(self._core, self._cmd_group)
 		return self._peak
 
-	def clone(self) -> 'Shr':
+	def clone(self) -> 'ShrCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Shr(self._core, self._cmd_group.parent)
+		new_group = ShrCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
