@@ -3,7 +3,7 @@ from ........Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Rmarker:
+class RmarkerCls:
 	"""Rmarker commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Rmarker:
 	def location(self):
 		"""location commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_location'):
-			from .Location import Location
-			self._location = Location(self._core, self._cmd_group)
+			from .Location import LocationCls
+			self._location = LocationCls(self._core, self._cmd_group)
 		return self._location
 
-	def clone(self) -> 'Rmarker':
+	def clone(self) -> 'RmarkerCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Rmarker(self._core, self._cmd_group.parent)
+		new_group = RmarkerCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
