@@ -3,7 +3,7 @@ from .........Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Minimum:
+class MinimumCls:
 	"""Minimum commands group definition. 4 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Minimum:
 	def width(self):
 		"""width commands group. 3 Sub-classes, 1 commands."""
 		if not hasattr(self, '_width'):
-			from .Width import Width
-			self._width = Width(self._core, self._cmd_group)
+			from .Width import WidthCls
+			self._width = WidthCls(self._core, self._cmd_group)
 		return self._width
 
-	def clone(self) -> 'Minimum':
+	def clone(self) -> 'MinimumCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Minimum(self._core, self._cmd_group.parent)
+		new_group = MinimumCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
