@@ -4,7 +4,7 @@ from .......Internal import Conversions
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Resolution:
+class ResolutionCls:
 	"""Resolution commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -15,8 +15,8 @@ class Resolution:
 	def auto(self):
 		"""auto commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_auto'):
-			from .Auto import Auto
-			self._auto = Auto(self._core, self._cmd_group)
+			from .Auto import AutoCls
+			self._auto = AutoCls(self._core, self._cmd_group)
 		return self._auto
 
 	def get(self) -> float:
@@ -27,10 +27,10 @@ class Resolution:
 		response = self._core.io.query_str(f'SENSe:BWIDth:RESolution?')
 		return Conversions.str_to_float(response)
 
-	def clone(self) -> 'Resolution':
+	def clone(self) -> 'ResolutionCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Resolution(self._core, self._cmd_group.parent)
+		new_group = ResolutionCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
