@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Length:
+class LengthCls:
 	"""Length commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Length:
 	def chips(self):
 		"""chips commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_chips'):
-			from .Chips import Chips
-			self._chips = Chips(self._core, self._cmd_group)
+			from .Chips import ChipsCls
+			self._chips = ChipsCls(self._core, self._cmd_group)
 		return self._chips
 
-	def clone(self) -> 'Length':
+	def clone(self) -> 'LengthCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Length(self._core, self._cmd_group.parent)
+		new_group = LengthCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
