@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Payload:
+class PayloadCls:
 	"""Payload commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Payload:
 	def max(self):
 		"""max commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_max'):
-			from .Max import Max
-			self._max = Max(self._core, self._cmd_group)
+			from .Max import MaxCls
+			self._max = MaxCls(self._core, self._cmd_group)
 		return self._max
 
-	def clone(self) -> 'Payload':
+	def clone(self) -> 'PayloadCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Payload(self._core, self._cmd_group.parent)
+		new_group = PayloadCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
