@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Evaluation:
+class EvaluationCls:
 	"""Evaluation commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Evaluation:
 	def offset(self):
 		"""offset commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_offset'):
-			from .Offset import Offset
-			self._offset = Offset(self._core, self._cmd_group)
+			from .Offset import OffsetCls
+			self._offset = OffsetCls(self._core, self._cmd_group)
 		return self._offset
 
-	def clone(self) -> 'Evaluation':
+	def clone(self) -> 'EvaluationCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Evaluation(self._core, self._cmd_group.parent)
+		new_group = EvaluationCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
