@@ -3,7 +3,7 @@ from .........Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Absolute:
+class AbsoluteCls:
 	"""Absolute commands group definition. 2 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class Absolute:
 	def start(self):
 		"""start commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_start'):
-			from .Start import Start
-			self._start = Start(self._core, self._cmd_group)
+			from .Start import StartCls
+			self._start = StartCls(self._core, self._cmd_group)
 		return self._start
 
 	@property
 	def stop(self):
 		"""stop commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_stop'):
-			from .Stop import Stop
-			self._stop = Stop(self._core, self._cmd_group)
+			from .Stop import StopCls
+			self._stop = StopCls(self._core, self._cmd_group)
 		return self._stop
 
-	def clone(self) -> 'Absolute':
+	def clone(self) -> 'AbsoluteCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Absolute(self._core, self._cmd_group.parent)
+		new_group = AbsoluteCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
