@@ -3,7 +3,7 @@ from ........Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Points:
+class PointsCls:
 	"""Points commands group definition. 2 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Points:
 	def minimum(self):
 		"""minimum commands group. 1 Sub-classes, 0 commands."""
 		if not hasattr(self, '_minimum'):
-			from .Minimum import Minimum
-			self._minimum = Minimum(self._core, self._cmd_group)
+			from .Minimum import MinimumCls
+			self._minimum = MinimumCls(self._core, self._cmd_group)
 		return self._minimum
 
-	def clone(self) -> 'Points':
+	def clone(self) -> 'PointsCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Points(self._core, self._cmd_group.parent)
+		new_group = PointsCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
