@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Statistics:
+class StatisticsCls:
 	"""Statistics commands group definition. 3 total commands, 3 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,30 +14,30 @@ class Statistics:
 	def count(self):
 		"""count commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_count'):
-			from .Count import Count
-			self._count = Count(self._core, self._cmd_group)
+			from .Count import CountCls
+			self._count = CountCls(self._core, self._cmd_group)
 		return self._count
 
 	@property
 	def group(self):
 		"""group commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_group'):
-			from .Group import Group
-			self._group = Group(self._core, self._cmd_group)
+			from .Group import GroupCls
+			self._group = GroupCls(self._core, self._cmd_group)
 		return self._group
 
 	@property
 	def range(self):
 		"""range commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_range'):
-			from .Range import Range
-			self._range = Range(self._core, self._cmd_group)
+			from .Range import RangeCls
+			self._range = RangeCls(self._core, self._cmd_group)
 		return self._range
 
-	def clone(self) -> 'Statistics':
+	def clone(self) -> 'StatisticsCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Statistics(self._core, self._cmd_group.parent)
+		new_group = StatisticsCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
