@@ -5,7 +5,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Data:
+class DataCls:
 	"""Data commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -16,8 +16,8 @@ class Data:
 	def memory(self):
 		"""memory commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_memory'):
-			from .Memory import Memory
-			self._memory = Memory(self._core, self._cmd_group)
+			from .Memory import MemoryCls
+			self._memory = MemoryCls(self._core, self._cmd_group)
 		return self._memory
 
 	def get(self) -> List[float]:
@@ -28,10 +28,10 @@ class Data:
 		response = self._core.io.query_bin_or_ascii_float_list_with_opc(f'FORMAT REAL,32;TRACe:IQ:DATA?')
 		return response
 
-	def clone(self) -> 'Data':
+	def clone(self) -> 'DataCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Data(self._core, self._cmd_group.parent)
+		new_group = DataCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
