@@ -3,7 +3,7 @@ from ........Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Fixed:
+class FixedCls:
 	"""Fixed commands group definition. 5 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class Fixed:
 	def rpoint(self):
 		"""rpoint commands group. 3 Sub-classes, 0 commands."""
 		if not hasattr(self, '_rpoint'):
-			from .Rpoint import Rpoint
-			self._rpoint = Rpoint(self._core, self._cmd_group)
+			from .Rpoint import RpointCls
+			self._rpoint = RpointCls(self._core, self._cmd_group)
 		return self._rpoint
 
 	@property
 	def state(self):
 		"""state commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_state'):
-			from .State import State
-			self._state = State(self._core, self._cmd_group)
+			from .State import StateCls
+			self._state = StateCls(self._core, self._cmd_group)
 		return self._state
 
-	def clone(self) -> 'Fixed':
+	def clone(self) -> 'FixedCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Fixed(self._core, self._cmd_group.parent)
+		new_group = FixedCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
