@@ -4,7 +4,7 @@ from ....... import repcap
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Next:
+class NextCls:
 	"""Next commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,7 +14,7 @@ class Next:
 	def set(self, window=repcap.Window.Default, deltaMarker=repcap.DeltaMarker.Default, opc_timeout_ms: int = -1) -> None:
 		"""SCPI: CALCulate<n>:DELTamarker<m>:MINimum:NEXT \n
 		Snippet: driver.applications.k14Xnr5G.calculate.deltaMarker.minimum.next.set(window = repcap.Window.Default, deltaMarker = repcap.DeltaMarker.Default) \n
-		This command moves a marker to the next higher minimum value. \n
+		This command moves a marker to the next minimum peak value. \n
 			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
 			:param deltaMarker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'DeltaMarker')
 			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
