@@ -3,7 +3,7 @@ from ..........Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Ap:
+class ApCls:
 	"""Ap commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Ap:
 	def uers(self):
 		"""uers commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_uers'):
-			from .Uers import Uers
-			self._uers = Uers(self._core, self._cmd_group)
+			from .Uers import UersCls
+			self._uers = UersCls(self._core, self._cmd_group)
 		return self._uers
 
-	def clone(self) -> 'Ap':
+	def clone(self) -> 'ApCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Ap(self._core, self._cmd_group.parent)
+		new_group = ApCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
