@@ -3,7 +3,7 @@ from ............Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Slot:
+class SlotCls:
 	"""Slot commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Slot:
 	def aperiodic(self):
 		"""aperiodic commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_aperiodic'):
-			from .Aperiodic import Aperiodic
-			self._aperiodic = Aperiodic(self._core, self._cmd_group)
+			from .Aperiodic import AperiodicCls
+			self._aperiodic = AperiodicCls(self._core, self._cmd_group)
 		return self._aperiodic
 
-	def clone(self) -> 'Slot':
+	def clone(self) -> 'SlotCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Slot(self._core, self._cmd_group.parent)
+		new_group = SlotCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
