@@ -3,7 +3,7 @@ from ..........Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Mbsfn:
+class MbsfnCls:
 	"""Mbsfn commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Mbsfn:
 	def subframe(self):
 		"""subframe commands group. 1 Sub-classes, 0 commands."""
 		if not hasattr(self, '_subframe'):
-			from .Subframe import Subframe
-			self._subframe = Subframe(self._core, self._cmd_group)
+			from .Subframe import SubframeCls
+			self._subframe = SubframeCls(self._core, self._cmd_group)
 		return self._subframe
 
-	def clone(self) -> 'Mbsfn':
+	def clone(self) -> 'MbsfnCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Mbsfn(self._core, self._cmd_group.parent)
+		new_group = MbsfnCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
