@@ -3,7 +3,7 @@ from ..........Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Sss:
+class SssCls:
 	"""Sss commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Sss:
 	def power(self):
 		"""power commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_power'):
-			from .Power import Power
-			self._power = Power(self._core, self._cmd_group)
+			from .Power import PowerCls
+			self._power = PowerCls(self._core, self._cmd_group)
 		return self._power
 
-	def clone(self) -> 'Sss':
+	def clone(self) -> 'SssCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Sss(self._core, self._cmd_group.parent)
+		new_group = SssCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
