@@ -3,7 +3,7 @@ from ........Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Mimo:
+class MimoCls:
 	"""Mimo commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Mimo:
 	def crosstalk(self):
 		"""crosstalk commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_crosstalk'):
-			from .Crosstalk import Crosstalk
-			self._crosstalk = Crosstalk(self._core, self._cmd_group)
+			from .Crosstalk import CrosstalkCls
+			self._crosstalk = CrosstalkCls(self._core, self._cmd_group)
 		return self._crosstalk
 
-	def clone(self) -> 'Mimo':
+	def clone(self) -> 'MimoCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Mimo(self._core, self._cmd_group.parent)
+		new_group = MimoCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
