@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class MsHelper:
+class MsHelperCls:
 	"""MsHelper commands group definition. 2 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class MsHelper:
 	def conductor(self):
 		"""conductor commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_conductor'):
-			from .Conductor import Conductor
-			self._conductor = Conductor(self._core, self._cmd_group)
+			from .Conductor import ConductorCls
+			self._conductor = ConductorCls(self._core, self._cmd_group)
 		return self._conductor
 
 	@property
 	def mhelper(self):
 		"""mhelper commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_mhelper'):
-			from .Mhelper import Mhelper
-			self._mhelper = Mhelper(self._core, self._cmd_group)
+			from .Mhelper import MhelperCls
+			self._mhelper = MhelperCls(self._core, self._cmd_group)
 		return self._mhelper
 
-	def clone(self) -> 'MsHelper':
+	def clone(self) -> 'MsHelperCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = MsHelper(self._core, self._cmd_group.parent)
+		new_group = MsHelperCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
