@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Oran:
+class OranCls:
 	"""Oran commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Oran:
 	def tcase(self):
 		"""tcase commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_tcase'):
-			from .Tcase import Tcase
-			self._tcase = Tcase(self._core, self._cmd_group)
+			from .Tcase import TcaseCls
+			self._tcase = TcaseCls(self._core, self._cmd_group)
 		return self._tcase
 
-	def clone(self) -> 'Oran':
+	def clone(self) -> 'OranCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Oran(self._core, self._cmd_group.parent)
+		new_group = OranCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
