@@ -3,7 +3,7 @@ from ........Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Signal:
+class SignalCls:
 	"""Signal commands group definition. 2 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class Signal:
 	def typePy(self):
 		"""typePy commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_typePy'):
-			from .TypePy import TypePy
-			self._typePy = TypePy(self._core, self._cmd_group)
+			from .TypePy import TypePyCls
+			self._typePy = TypePyCls(self._core, self._cmd_group)
 		return self._typePy
 
 	@property
 	def tx(self):
 		"""tx commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_tx'):
-			from .Tx import Tx
-			self._tx = Tx(self._core, self._cmd_group)
+			from .Tx import TxCls
+			self._tx = TxCls(self._core, self._cmd_group)
 		return self._tx
 
-	def clone(self) -> 'Signal':
+	def clone(self) -> 'SignalCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Signal(self._core, self._cmd_group.parent)
+		new_group = SignalCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
