@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Simulation:
+class SimulationCls:
 	"""Simulation commands group definition. 2 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Simulation:
 	def signal(self):
 		"""signal commands group. 2 Sub-classes, 0 commands."""
 		if not hasattr(self, '_signal'):
-			from .Signal import Signal
-			self._signal = Signal(self._core, self._cmd_group)
+			from .Signal import SignalCls
+			self._signal = SignalCls(self._core, self._cmd_group)
 		return self._signal
 
-	def clone(self) -> 'Simulation':
+	def clone(self) -> 'SimulationCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Simulation(self._core, self._cmd_group.parent)
+		new_group = SimulationCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
