@@ -3,7 +3,7 @@ from ............Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Fhopping:
+class FhoppingCls:
 	"""Fhopping commands group definition. 3 total commands, 3 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,30 +14,30 @@ class Fhopping:
 	def bhop(self):
 		"""bhop commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_bhop'):
-			from .Bhop import Bhop
-			self._bhop = Bhop(self._core, self._cmd_group)
+			from .Bhop import BhopCls
+			self._bhop = BhopCls(self._core, self._cmd_group)
 		return self._bhop
 
 	@property
 	def bsrs(self):
 		"""bsrs commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_bsrs'):
-			from .Bsrs import Bsrs
-			self._bsrs = Bsrs(self._core, self._cmd_group)
+			from .Bsrs import BsrsCls
+			self._bsrs = BsrsCls(self._core, self._cmd_group)
 		return self._bsrs
 
 	@property
 	def csrs(self):
 		"""csrs commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_csrs'):
-			from .Csrs import Csrs
-			self._csrs = Csrs(self._core, self._cmd_group)
+			from .Csrs import CsrsCls
+			self._csrs = CsrsCls(self._core, self._cmd_group)
 		return self._csrs
 
-	def clone(self) -> 'Fhopping':
+	def clone(self) -> 'FhoppingCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Fhopping(self._core, self._cmd_group.parent)
+		new_group = FhoppingCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
