@@ -3,7 +3,7 @@ from ............Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Sequence:
+class SequenceCls:
 	"""Sequence commands group definition. 3 total commands, 3 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,30 +14,30 @@ class Sequence:
 	def cshift(self):
 		"""cshift commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_cshift'):
-			from .Cshift import Cshift
-			self._cshift = Cshift(self._core, self._cmd_group)
+			from .Cshift import CshiftCls
+			self._cshift = CshiftCls(self._core, self._cmd_group)
 		return self._cshift
 
 	@property
 	def hopping(self):
 		"""hopping commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_hopping'):
-			from .Hopping import Hopping
-			self._hopping = Hopping(self._core, self._cmd_group)
+			from .Hopping import HoppingCls
+			self._hopping = HoppingCls(self._core, self._cmd_group)
 		return self._hopping
 
 	@property
 	def id(self):
 		"""id commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_id'):
-			from .Id import Id
-			self._id = Id(self._core, self._cmd_group)
+			from .Id import IdCls
+			self._id = IdCls(self._core, self._cmd_group)
 		return self._id
 
-	def clone(self) -> 'Sequence':
+	def clone(self) -> 'SequenceCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Sequence(self._core, self._cmd_group.parent)
+		new_group = SequenceCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
