@@ -3,7 +3,7 @@ from ............Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Tcomb:
+class TcombCls:
 	"""Tcomb commands group definition. 2 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class Tcomb:
 	def offset(self):
 		"""offset commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_offset'):
-			from .Offset import Offset
-			self._offset = Offset(self._core, self._cmd_group)
+			from .Offset import OffsetCls
+			self._offset = OffsetCls(self._core, self._cmd_group)
 		return self._offset
 
 	@property
 	def value(self):
 		"""value commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_value'):
-			from .Value import Value
-			self._value = Value(self._core, self._cmd_group)
+			from .Value import ValueCls
+			self._value = ValueCls(self._core, self._cmd_group)
 		return self._value
 
-	def clone(self) -> 'Tcomb':
+	def clone(self) -> 'TcombCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Tcomb(self._core, self._cmd_group.parent)
+		new_group = TcombCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
