@@ -3,7 +3,7 @@ from ..........Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Pusch:
+class PuschCls:
 	"""Pusch commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Pusch:
 	def ap(self):
 		"""ap commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_ap'):
-			from .Ap import Ap
-			self._ap = Ap(self._core, self._cmd_group)
+			from .Ap import ApCls
+			self._ap = ApCls(self._core, self._cmd_group)
 		return self._ap
 
-	def clone(self) -> 'Pusch':
+	def clone(self) -> 'PuschCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Pusch(self._core, self._cmd_group.parent)
+		new_group = PuschCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
