@@ -5,7 +5,7 @@ from ......... import repcap
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class TbOffset:
+class TbOffsetCls:
 	"""TbOffset commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -15,9 +15,9 @@ class TbOffset:
 	def get(self, carrierComponent=repcap.CarrierComponent.Default) -> float:
 		"""SCPI: CONFigure[:NR5G]:UL[:CC<cc>]:RPA:TBOFfset \n
 		Snippet: value: float = driver.applications.k14Xnr5G.configure.nr5G.uplink.cc.rpa.tbOffset.get(carrierComponent = repcap.CarrierComponent.Default) \n
-		No command help available \n
+		This command queries the TxBW offset of the reference point A. \n
 			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
-			:return: offset: No help available"""
+			:return: offset: numeric value Unit: Hz"""
 		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
 		response = self._core.io.query_str(f'CONFigure:NR5G:UL:CC{carrierComponent_cmd_val}:RPA:TBOFfset?')
 		return Conversions.str_to_float(response)
