@@ -3,7 +3,7 @@ from ......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Settings:
+class SettingsCls:
 	"""Settings commands group definition. 4 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class Settings:
 	def nr5G(self):
 		"""nr5G commands group. 2 Sub-classes, 1 commands."""
 		if not hasattr(self, '_nr5G'):
-			from .Nr5G import Nr5G
-			self._nr5G = Nr5G(self._core, self._cmd_group)
+			from .Nr5G import Nr5GCls
+			self._nr5G = Nr5GCls(self._core, self._cmd_group)
 		return self._nr5G
 
 	@property
 	def rf(self):
 		"""rf commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_rf'):
-			from .Rf import Rf
-			self._rf = Rf(self._core, self._cmd_group)
+			from .Rf import RfCls
+			self._rf = RfCls(self._core, self._cmd_group)
 		return self._rf
 
-	def clone(self) -> 'Settings':
+	def clone(self) -> 'SettingsCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Settings(self._core, self._cmd_group.parent)
+		new_group = SettingsCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
