@@ -4,7 +4,7 @@ from ........Internal import Conversions
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Us1K:
+class Us1KCls:
 	"""Us1K commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,7 +14,9 @@ class Us1K:
 	def get(self) -> float:
 		"""SCPI: FETCh:ALL:SUMMary:EVM:US1K \n
 		Snippet: value: float = driver.applications.k14Xnr5G.fetch.all.summary.evm.us1K.get() \n
-		No command help available \n
-			:return: evm: No help available"""
+		This command queries the EVM of all PUSCH resource elements with a 1024QAM modulation.
+			INTRO_CMD_HELP: method RsFsw.Applications.K14x_Nr5G.Fetch.All.Summary.Evm.Usqp.get_ queries the average result over all carriers. Prerequisites: \n
+			- Select to evaluate all carriers ([SENSe:]NR5G:RSUMmary:CCResult) . \n
+			:return: evm: EVM in % or dB."""
 		response = self._core.io.query_str(f'FETCh:ALL:SUMMary:EVM:US1K?')
 		return Conversions.str_to_float(response)
