@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Summary:
+class SummaryCls:
 	"""Summary commands group definition. 27 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class Summary:
 	def evm(self):
 		"""evm commands group. 26 Sub-classes, 0 commands."""
 		if not hasattr(self, '_evm'):
-			from .Evm import Evm
-			self._evm = Evm(self._core, self._cmd_group)
+			from .Evm import EvmCls
+			self._evm = EvmCls(self._core, self._cmd_group)
 		return self._evm
 
 	@property
 	def power(self):
 		"""power commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_power'):
-			from .Power import Power
-			self._power = Power(self._core, self._cmd_group)
+			from .Power import PowerCls
+			self._power = PowerCls(self._core, self._cmd_group)
 		return self._power
 
-	def clone(self) -> 'Summary':
+	def clone(self) -> 'SummaryCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Summary(self._core, self._cmd_group.parent)
+		new_group = SummaryCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
