@@ -3,7 +3,7 @@ from ......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class All:
+class AllCls:
 	"""All commands group definition. 27 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class All:
 	def summary(self):
 		"""summary commands group. 2 Sub-classes, 0 commands."""
 		if not hasattr(self, '_summary'):
-			from .Summary import Summary
-			self._summary = Summary(self._core, self._cmd_group)
+			from .Summary import SummaryCls
+			self._summary = SummaryCls(self._core, self._cmd_group)
 		return self._summary
 
-	def clone(self) -> 'All':
+	def clone(self) -> 'AllCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = All(self._core, self._cmd_group.parent)
+		new_group = AllCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
