@@ -5,7 +5,7 @@ from ......... import repcap
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class All:
+class AllCls:
 	"""All commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -18,7 +18,7 @@ class All:
 		This command queries all results in the numerical result summary. \n
 			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
 			:param frame: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Frame')
-			:return: all: No help available"""
+			:return: all_py: No help available"""
 		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
 		frame_cmd_val = self._cmd_group.get_repcap_cmd_value(frame, repcap.Frame)
 		response = self._core.io.query_str(f'FETCh:CC{carrierComponent_cmd_val}:ISRC:FRAMe{frame_cmd_val}:SUMMary:ALL?')
