@@ -3,7 +3,7 @@ from ..........Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Rsrp:
+class RsrpCls:
 	"""Rsrp commands group definition. 6 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class Rsrp:
 	def csi(self):
 		"""csi commands group. 3 Sub-classes, 0 commands."""
 		if not hasattr(self, '_csi'):
-			from .Csi import Csi
-			self._csi = Csi(self._core, self._cmd_group)
+			from .Csi import CsiCls
+			self._csi = CsiCls(self._core, self._cmd_group)
 		return self._csi
 
 	@property
 	def ss(self):
 		"""ss commands group. 3 Sub-classes, 0 commands."""
 		if not hasattr(self, '_ss'):
-			from .Ss import Ss
-			self._ss = Ss(self._core, self._cmd_group)
+			from .Ss import SsCls
+			self._ss = SsCls(self._core, self._cmd_group)
 		return self._ss
 
-	def clone(self) -> 'Rsrp':
+	def clone(self) -> 'RsrpCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Rsrp(self._core, self._cmd_group.parent)
+		new_group = RsrpCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
