@@ -3,7 +3,7 @@ from ........Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Summary:
+class SummaryCls:
 	"""Summary commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Summary:
 	def tframe(self):
 		"""tframe commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_tframe'):
-			from .Tframe import Tframe
-			self._tframe = Tframe(self._core, self._cmd_group)
+			from .Tframe import TframeCls
+			self._tframe = TframeCls(self._core, self._cmd_group)
 		return self._tframe
 
-	def clone(self) -> 'Summary':
+	def clone(self) -> 'SummaryCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Summary(self._core, self._cmd_group.parent)
+		new_group = SummaryCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
