@@ -4,7 +4,7 @@ from .......Internal import Conversions
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Auto:
+class AutoCls:
 	"""Auto commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -15,7 +15,7 @@ class Auto:
 		"""SCPI: INPut:DIQ:SRATe:AUTO \n
 		Snippet: driver.applications.k14Xnr5G.inputPy.diq.symbolRate.auto.set(state = False) \n
 		If enabled, the sample rate of the digital I/Q input signal is set automatically by the connected device. This command is
-		only available if the optional Digital Baseband Interface is installed. \n
+		only available if the optional 'Digital Baseband' interface is installed. \n
 			:param state: ON | OFF | 1 | 0
 		"""
 		param = Conversions.bool_to_str(state)
@@ -25,7 +25,7 @@ class Auto:
 		"""SCPI: INPut:DIQ:SRATe:AUTO \n
 		Snippet: value: bool = driver.applications.k14Xnr5G.inputPy.diq.symbolRate.auto.get() \n
 		If enabled, the sample rate of the digital I/Q input signal is set automatically by the connected device. This command is
-		only available if the optional Digital Baseband Interface is installed. \n
+		only available if the optional 'Digital Baseband' interface is installed. \n
 			:return: state: ON | OFF | 1 | 0"""
 		response = self._core.io.query_str(f'INPut:DIQ:SRATe:AUTO?')
 		return Conversions.str_to_bool(response)
