@@ -5,7 +5,7 @@ from ..... import enums
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Dpath:
+class DpathCls:
 	"""Dpath commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -15,7 +15,8 @@ class Dpath:
 	def set(self, state: enums.AutoOrOff) -> None:
 		"""SCPI: INPut:DPATh \n
 		Snippet: driver.applications.k14Xnr5G.inputPy.dpath.set(state = enums.AutoOrOff.AUTO) \n
-		Enables or disables the use of the direct path for frequencies close to 0 Hz. \n
+		Enables or disables the use of the direct path for frequencies close to 0 Hz. If an external frontend is active, the
+		direct path is always used. \n
 			:param state: No help available
 		"""
 		param = Conversions.enum_scalar_to_str(state, enums.AutoOrOff)
@@ -25,7 +26,8 @@ class Dpath:
 	def get(self) -> enums.AutoOrOff:
 		"""SCPI: INPut:DPATh \n
 		Snippet: value: enums.AutoOrOff = driver.applications.k14Xnr5G.inputPy.dpath.get() \n
-		Enables or disables the use of the direct path for frequencies close to 0 Hz. \n
+		Enables or disables the use of the direct path for frequencies close to 0 Hz. If an external frontend is active, the
+		direct path is always used. \n
 			:return: state: No help available"""
 		response = self._core.io.query_str(f'INPut:DPATh?')
 		return Conversions.str_to_scalar_enum(response, enums.AutoOrOff)
