@@ -3,7 +3,7 @@ from ......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class FilterPy:
+class FilterPyCls:
 	"""FilterPy commands group definition. 2 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class FilterPy:
 	def hpass(self):
 		"""hpass commands group. 1 Sub-classes, 0 commands."""
 		if not hasattr(self, '_hpass'):
-			from .Hpass import Hpass
-			self._hpass = Hpass(self._core, self._cmd_group)
+			from .Hpass import HpassCls
+			self._hpass = HpassCls(self._core, self._cmd_group)
 		return self._hpass
 
 	@property
 	def yig(self):
 		"""yig commands group. 1 Sub-classes, 0 commands."""
 		if not hasattr(self, '_yig'):
-			from .Yig import Yig
-			self._yig = Yig(self._core, self._cmd_group)
+			from .Yig import YigCls
+			self._yig = YigCls(self._core, self._cmd_group)
 		return self._yig
 
-	def clone(self) -> 'FilterPy':
+	def clone(self) -> 'FilterPyCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = FilterPy(self._core, self._cmd_group.parent)
+		new_group = FilterPyCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
