@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class CapMode:
+class CapModeCls:
 	"""CapMode commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class CapMode:
 	def iq(self):
 		"""iq commands group. 1 Sub-classes, 0 commands."""
 		if not hasattr(self, '_iq'):
-			from .Iq import Iq
-			self._iq = Iq(self._core, self._cmd_group)
+			from .Iq import IqCls
+			self._iq = IqCls(self._core, self._cmd_group)
 		return self._iq
 
-	def clone(self) -> 'CapMode':
+	def clone(self) -> 'CapModeCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = CapMode(self._core, self._cmd_group.parent)
+		new_group = CapModeCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
