@@ -3,7 +3,7 @@ from ......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Rf:
+class RfCls:
 	"""Rf commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Rf:
 	def capMode(self):
 		"""capMode commands group. 1 Sub-classes, 0 commands."""
 		if not hasattr(self, '_capMode'):
-			from .CapMode import CapMode
-			self._capMode = CapMode(self._core, self._cmd_group)
+			from .CapMode import CapModeCls
+			self._capMode = CapModeCls(self._core, self._cmd_group)
 		return self._capMode
 
-	def clone(self) -> 'Rf':
+	def clone(self) -> 'RfCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Rf(self._core, self._cmd_group.parent)
+		new_group = RfCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
