@@ -3,7 +3,7 @@ from ......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Settings:
+class SettingsCls:
 	"""Settings commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -13,14 +13,14 @@ class Settings:
 	def set(self) -> None:
 		"""SCPI: MMEMory:LOAD:SETTings \n
 		Snippet: driver.applications.k14Xnr5G.massMemory.load.settings.set() \n
-		No command help available \n
+		Restores the settings of the last measurement sequence in combined mode. \n
 		"""
 		self._core.io.write(f'MMEMory:LOAD:SETTings')
 
 	def set_with_opc(self, opc_timeout_ms: int = -1) -> None:
 		"""SCPI: MMEMory:LOAD:SETTings \n
 		Snippet: driver.applications.k14Xnr5G.massMemory.load.settings.set_with_opc() \n
-		No command help available \n
+		Restores the settings of the last measurement sequence in combined mode. \n
 		Same as set, but waits for the operation to complete before continuing further. Use the RsFsw.utilities.opc_timeout_set() to set the timeout value. \n
 			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
 		self._core.io.write_with_opc(f'MMEMory:LOAD:SETTings', opc_timeout_ms)
