@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Tmodel:
+class TmodelCls:
 	"""Tmodel commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Tmodel:
 	def cc(self):
 		"""cc commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_cc'):
-			from .Cc import Cc
-			self._cc = Cc(self._core, self._cmd_group)
+			from .Cc import CcCls
+			self._cc = CcCls(self._core, self._cmd_group)
 		return self._cc
 
-	def clone(self) -> 'Tmodel':
+	def clone(self) -> 'TmodelCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Tmodel(self._core, self._cmd_group.parent)
+		new_group = TmodelCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
