@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Iq:
+class IqCls:
 	"""Iq commands group definition. 4 total commands, 3 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,30 +14,30 @@ class Iq:
 	def formatPy(self):
 		"""formatPy commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_formatPy'):
-			from .FormatPy import FormatPy
-			self._formatPy = FormatPy(self._core, self._cmd_group)
+			from .FormatPy import FormatPyCls
+			self._formatPy = FormatPyCls(self._core, self._cmd_group)
 		return self._formatPy
 
 	@property
 	def comment(self):
 		"""comment commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_comment'):
-			from .Comment import Comment
-			self._comment = Comment(self._core, self._cmd_group)
+			from .Comment import CommentCls
+			self._comment = CommentCls(self._core, self._cmd_group)
 		return self._comment
 
 	@property
 	def state(self):
 		"""state commands group. 1 Sub-classes, 1 commands."""
 		if not hasattr(self, '_state'):
-			from .State import State
-			self._state = State(self._core, self._cmd_group)
+			from .State import StateCls
+			self._state = StateCls(self._core, self._cmd_group)
 		return self._state
 
-	def clone(self) -> 'Iq':
+	def clone(self) -> 'IqCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Iq(self._core, self._cmd_group.parent)
+		new_group = IqCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
