@@ -3,7 +3,7 @@ from .....Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class MassMemory:
+class MassMemoryCls:
 	"""MassMemory commands group definition. 21 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class MassMemory:
 	def load(self):
 		"""load commands group. 5 Sub-classes, 0 commands."""
 		if not hasattr(self, '_load'):
-			from .Load import Load
-			self._load = Load(self._core, self._cmd_group)
+			from .Load import LoadCls
+			self._load = LoadCls(self._core, self._cmd_group)
 		return self._load
 
 	@property
 	def store(self):
 		"""store commands group. 7 Sub-classes, 0 commands."""
 		if not hasattr(self, '_store'):
-			from .Store import Store
-			self._store = Store(self._core, self._cmd_group)
+			from .Store import StoreCls
+			self._store = StoreCls(self._core, self._cmd_group)
 		return self._store
 
-	def clone(self) -> 'MassMemory':
+	def clone(self) -> 'MassMemoryCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = MassMemory(self._core, self._cmd_group.parent)
+		new_group = MassMemoryCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
