@@ -3,7 +3,7 @@ from ......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Diq:
+class DiqCls:
 	"""Diq commands group definition. 2 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class Diq:
 	def cdevice(self):
 		"""cdevice commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_cdevice'):
-			from .Cdevice import Cdevice
-			self._cdevice = Cdevice(self._core, self._cmd_group)
+			from .Cdevice import CdeviceCls
+			self._cdevice = CdeviceCls(self._core, self._cmd_group)
 		return self._cdevice
 
 	@property
 	def state(self):
 		"""state commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_state'):
-			from .State import State
-			self._state = State(self._core, self._cmd_group)
+			from .State import StateCls
+			self._state = StateCls(self._core, self._cmd_group)
 		return self._state
 
-	def clone(self) -> 'Diq':
+	def clone(self) -> 'DiqCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Diq(self._core, self._cmd_group.parent)
+		new_group = DiqCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
