@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Configure:
+class ConfigureCls:
 	"""Configure commands group definition. 4 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class Configure:
 	def hysteresis(self):
 		"""hysteresis commands group. 2 Sub-classes, 0 commands."""
 		if not hasattr(self, '_hysteresis'):
-			from .Hysteresis import Hysteresis
-			self._hysteresis = Hysteresis(self._core, self._cmd_group)
+			from .Hysteresis import HysteresisCls
+			self._hysteresis = HysteresisCls(self._core, self._cmd_group)
 		return self._hysteresis
 
 	@property
 	def level(self):
 		"""level commands group. 1 Sub-classes, 0 commands."""
 		if not hasattr(self, '_level'):
-			from .Level import Level
-			self._level = Level(self._core, self._cmd_group)
+			from .Level import LevelCls
+			self._level = LevelCls(self._core, self._cmd_group)
 		return self._level
 
-	def clone(self) -> 'Configure':
+	def clone(self) -> 'ConfigureCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Configure(self._core, self._cmd_group.parent)
+		new_group = ConfigureCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
