@@ -3,7 +3,7 @@ from ........Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Carrier:
+class CarrierCls:
 	"""Carrier commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Carrier:
 	def select(self):
 		"""select commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_select'):
-			from .Select import Select
-			self._select = Select(self._core, self._cmd_group)
+			from .Select import SelectCls
+			self._select = SelectCls(self._core, self._cmd_group)
 		return self._select
 
-	def clone(self) -> 'Carrier':
+	def clone(self) -> 'CarrierCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Carrier(self._core, self._cmd_group.parent)
+		new_group = CarrierCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
