@@ -3,8 +3,8 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Tracking:
-	"""Tracking commands group definition. 3 total commands, 3 Subgroups, 0 group commands"""
+class TrackingCls:
+	"""Tracking commands group definition. 4 total commands, 4 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
 		self._core = core
@@ -14,30 +14,38 @@ class Tracking:
 	def level(self):
 		"""level commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_level'):
-			from .Level import Level
-			self._level = Level(self._core, self._cmd_group)
+			from .Level import LevelCls
+			self._level = LevelCls(self._core, self._cmd_group)
 		return self._level
 
 	@property
 	def phase(self):
 		"""phase commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_phase'):
-			from .Phase import Phase
-			self._phase = Phase(self._core, self._cmd_group)
+			from .Phase import PhaseCls
+			self._phase = PhaseCls(self._core, self._cmd_group)
 		return self._phase
 
 	@property
 	def time(self):
 		"""time commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_time'):
-			from .Time import Time
-			self._time = Time(self._core, self._cmd_group)
+			from .Time import TimeCls
+			self._time = TimeCls(self._core, self._cmd_group)
 		return self._time
 
-	def clone(self) -> 'Tracking':
+	@property
+	def tput(self):
+		"""tput commands group. 1 Sub-classes, 0 commands."""
+		if not hasattr(self, '_tput'):
+			from .Tput import TputCls
+			self._tput = TputCls(self._core, self._cmd_group)
+		return self._tput
+
+	def clone(self) -> 'TrackingCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Tracking(self._core, self._cmd_group.parent)
+		new_group = TrackingCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
