@@ -3,7 +3,7 @@ from ..........Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Channel:
+class ChannelCls:
 	"""Channel commands group definition. 2 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Channel:
 	def count(self):
 		"""count commands group. 2 Sub-classes, 0 commands."""
 		if not hasattr(self, '_count'):
-			from .Count import Count
-			self._count = Count(self._core, self._cmd_group)
+			from .Count import CountCls
+			self._count = CountCls(self._core, self._cmd_group)
 		return self._count
 
-	def clone(self) -> 'Channel':
+	def clone(self) -> 'ChannelCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Channel(self._core, self._cmd_group.parent)
+		new_group = ChannelCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
