@@ -3,7 +3,7 @@ from .........Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Manual:
+class ManualCls:
 	"""Manual commands group definition. 2 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Manual:
 	def channel(self):
 		"""channel commands group. 1 Sub-classes, 0 commands."""
 		if not hasattr(self, '_channel'):
-			from .Channel import Channel
-			self._channel = Channel(self._core, self._cmd_group)
+			from .Channel import ChannelCls
+			self._channel = ChannelCls(self._core, self._cmd_group)
 		return self._channel
 
-	def clone(self) -> 'Manual':
+	def clone(self) -> 'ManualCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Manual(self._core, self._cmd_group.parent)
+		new_group = ManualCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
