@@ -3,7 +3,7 @@ from .........Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class State:
+class StateCls:
 	"""State commands group definition. 2 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class State:
 	def gap(self):
 		"""gap commands group. 1 Sub-classes, 0 commands."""
 		if not hasattr(self, '_gap'):
-			from .Gap import Gap
-			self._gap = Gap(self._core, self._cmd_group)
+			from .Gap import GapCls
+			self._gap = GapCls(self._core, self._cmd_group)
 		return self._gap
 
-	def clone(self) -> 'State':
+	def clone(self) -> 'StateCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = State(self._core, self._cmd_group.parent)
+		new_group = StateCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
