@@ -3,7 +3,7 @@ from ........Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Preset:
+class PresetCls:
 	"""Preset commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Preset:
 	def refLevel(self):
 		"""refLevel commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_refLevel'):
-			from .RefLevel import RefLevel
-			self._refLevel = RefLevel(self._core, self._cmd_group)
+			from .RefLevel import RefLevelCls
+			self._refLevel = RefLevelCls(self._core, self._cmd_group)
 		return self._refLevel
 
-	def clone(self) -> 'Preset':
+	def clone(self) -> 'PresetCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Preset(self._core, self._cmd_group.parent)
+		new_group = PresetCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
