@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Aclr:
+class AclrCls:
 	"""Aclr commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Aclr:
 	def iff(self):
 		"""iff commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_iff'):
-			from .Iff import Iff
-			self._iff = Iff(self._core, self._cmd_group)
+			from .Iff import IffCls
+			self._iff = IffCls(self._core, self._cmd_group)
 		return self._iff
 
-	def clone(self) -> 'Aclr':
+	def clone(self) -> 'AclrCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Aclr(self._core, self._cmd_group.parent)
+		new_group = AclrCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
