@@ -3,7 +3,7 @@ from ......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Communicate:
+class CommunicateCls:
 	"""Communicate commands group definition. 3 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Communicate:
 	def rdevice(self):
 		"""rdevice commands group. 1 Sub-classes, 0 commands."""
 		if not hasattr(self, '_rdevice'):
-			from .Rdevice import Rdevice
-			self._rdevice = Rdevice(self._core, self._cmd_group)
+			from .Rdevice import RdeviceCls
+			self._rdevice = RdeviceCls(self._core, self._cmd_group)
 		return self._rdevice
 
-	def clone(self) -> 'Communicate':
+	def clone(self) -> 'CommunicateCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Communicate(self._core, self._cmd_group.parent)
+		new_group = CommunicateCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
