@@ -3,7 +3,7 @@ from .....Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class System:
+class SystemCls:
 	"""System commands group definition. 3 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class System:
 	def communicate(self):
 		"""communicate commands group. 1 Sub-classes, 0 commands."""
 		if not hasattr(self, '_communicate'):
-			from .Communicate import Communicate
-			self._communicate = Communicate(self._core, self._cmd_group)
+			from .Communicate import CommunicateCls
+			self._communicate = CommunicateCls(self._core, self._cmd_group)
 		return self._communicate
 
-	def clone(self) -> 'System':
+	def clone(self) -> 'SystemCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = System(self._core, self._cmd_group.parent)
+		new_group = SystemCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
