@@ -3,7 +3,7 @@ from ......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class GrpDelay:
+class GrpDelayCls:
 	"""GrpDelay commands group definition. 3 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class GrpDelay:
 	def mode(self):
 		"""mode commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_mode'):
-			from .Mode import Mode
-			self._mode = Mode(self._core, self._cmd_group)
+			from .Mode import ModeCls
+			self._mode = ModeCls(self._core, self._cmd_group)
 		return self._mode
 
 	@property
 	def reference(self):
 		"""reference commands group. 1 Sub-classes, 1 commands."""
 		if not hasattr(self, '_reference'):
-			from .Reference import Reference
-			self._reference = Reference(self._core, self._cmd_group)
+			from .Reference import ReferenceCls
+			self._reference = ReferenceCls(self._core, self._cmd_group)
 		return self._reference
 
-	def clone(self) -> 'GrpDelay':
+	def clone(self) -> 'GrpDelayCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = GrpDelay(self._core, self._cmd_group.parent)
+		new_group = GrpDelayCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
