@@ -4,7 +4,7 @@ from ......Internal import Conversions
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class State:
+class StateCls:
 	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,7 +14,7 @@ class State:
 	def get(self) -> bool:
 		"""SCPI: CALibration:MCGD:STATe \n
 		Snippet: value: bool = driver.applications.k17Mcgd.calibration.mcgd.state.get() \n
-		This command queries the calibration status of the Multi-Carrier Group Delay application. \n
+		This command queries the calibration status of the Multi-Carrier 'Group Delay' application. \n
 			:return: state: ON | 1 Calibration has been performed, reference data is available. OFF | 0 Calibration has not yet been performed or is currently running, reference data is not yet available."""
 		response = self._core.io.query_str(f'CALibration:MCGD:STATe?')
 		return Conversions.str_to_bool(response)
