@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Carrier:
+class CarrierCls:
 	"""Carrier commands group definition. 2 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class Carrier:
 	def state(self):
 		"""state commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_state'):
-			from .State import State
-			self._state = State(self._core, self._cmd_group)
+			from .State import StateCls
+			self._state = StateCls(self._core, self._cmd_group)
 		return self._state
 
 	@property
 	def threshold(self):
 		"""threshold commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_threshold'):
-			from .Threshold import Threshold
-			self._threshold = Threshold(self._core, self._cmd_group)
+			from .Threshold import ThresholdCls
+			self._threshold = ThresholdCls(self._core, self._cmd_group)
 		return self._threshold
 
-	def clone(self) -> 'Carrier':
+	def clone(self) -> 'CarrierCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Carrier(self._core, self._cmd_group.parent)
+		new_group = CarrierCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
