@@ -3,7 +3,7 @@ from ........Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Aftm:
+class AftmCls:
 	"""Aftm commands group definition. 7 total commands, 3 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,30 +14,30 @@ class Aftm:
 	def state(self):
 		"""state commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_state'):
-			from .State import State
-			self._state = State(self._core, self._cmd_group)
+			from .State import StateCls
+			self._state = StateCls(self._core, self._cmd_group)
 		return self._state
 
 	@property
 	def frequency(self):
 		"""frequency commands group. 4 Sub-classes, 0 commands."""
 		if not hasattr(self, '_frequency'):
-			from .Frequency import Frequency
-			self._frequency = Frequency(self._core, self._cmd_group)
+			from .Frequency import FrequencyCls
+			self._frequency = FrequencyCls(self._core, self._cmd_group)
 		return self._frequency
 
 	@property
 	def ostate(self):
 		"""ostate commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_ostate'):
-			from .Ostate import Ostate
-			self._ostate = Ostate(self._core, self._cmd_group)
+			from .Ostate import OstateCls
+			self._ostate = OstateCls(self._core, self._cmd_group)
 		return self._ostate
 
-	def clone(self) -> 'Aftm':
+	def clone(self) -> 'AftmCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Aftm(self._core, self._cmd_group.parent)
+		new_group = AftmCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
