@@ -3,7 +3,7 @@ from ........Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Connection:
+class ConnectionCls:
 	"""Connection commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Connection:
 	def cstate(self):
 		"""cstate commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_cstate'):
-			from .Cstate import Cstate
-			self._cstate = Cstate(self._core, self._cmd_group)
+			from .Cstate import CstateCls
+			self._cstate = CstateCls(self._core, self._cmd_group)
 		return self._cstate
 
-	def clone(self) -> 'Connection':
+	def clone(self) -> 'ConnectionCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Connection(self._core, self._cmd_group.parent)
+		new_group = ConnectionCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
