@@ -3,7 +3,7 @@ from ......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Generator:
+class GeneratorCls:
 	"""Generator commands group definition. 21 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class Generator:
 	def mcgd(self):
 		"""mcgd commands group. 8 Sub-classes, 0 commands."""
 		if not hasattr(self, '_mcgd'):
-			from .Mcgd import Mcgd
-			self._mcgd = Mcgd(self._core, self._cmd_group)
+			from .Mcgd import McgdCls
+			self._mcgd = McgdCls(self._core, self._cmd_group)
 		return self._mcgd
 
 	@property
 	def rfOutput(self):
 		"""rfOutput commands group. 1 Sub-classes, 0 commands."""
 		if not hasattr(self, '_rfOutput'):
-			from .RfOutput import RfOutput
-			self._rfOutput = RfOutput(self._core, self._cmd_group)
+			from .RfOutput import RfOutputCls
+			self._rfOutput = RfOutputCls(self._core, self._cmd_group)
 		return self._rfOutput
 
-	def clone(self) -> 'Generator':
+	def clone(self) -> 'GeneratorCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Generator(self._core, self._cmd_group.parent)
+		new_group = GeneratorCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
