@@ -4,7 +4,7 @@ from .......Internal import Conversions
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Demodulation:
+class DemodulationCls:
 	"""Demodulation commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -15,7 +15,7 @@ class Demodulation:
 		"""SCPI: [SENSe]:ADEMod:BWIDth:DEModulation \n
 		Snippet: value: float = driver.applications.k17Mcgd.sense.ademod.bandwidth.demodulation.get() \n
 		This command queries the measurement bandwidth. Note that this command is maintained for compatibility reasons only. Use
-		[SENSe:]BANDwidth:DEMod? for new remote control programs. \n
+		[SENSe:]BANDwidth:DEMod for new remote control programs. \n
 			:return: span: Unit: HZ"""
 		response = self._core.io.query_str(f'SENSe:ADEMod:BWIDth:DEModulation?')
 		return Conversions.str_to_float(response)
