@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Bandwidth:
+class BandwidthCls:
 	"""Bandwidth commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Bandwidth:
 	def demodulation(self):
 		"""demodulation commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_demodulation'):
-			from .Demodulation import Demodulation
-			self._demodulation = Demodulation(self._core, self._cmd_group)
+			from .Demodulation import DemodulationCls
+			self._demodulation = DemodulationCls(self._core, self._cmd_group)
 		return self._demodulation
 
-	def clone(self) -> 'Bandwidth':
+	def clone(self) -> 'BandwidthCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Bandwidth(self._core, self._cmd_group.parent)
+		new_group = BandwidthCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
