@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class McPhase:
+class McPhaseCls:
 	"""McPhase commands group definition. 3 total commands, 3 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,30 +14,30 @@ class McPhase:
 	def method(self):
 		"""method commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_method'):
-			from .Method import Method
-			self._method = Method(self._core, self._cmd_group)
+			from .Method import MethodCls
+			self._method = MethodCls(self._core, self._cmd_group)
 		return self._method
 
 	@property
 	def state(self):
 		"""state commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_state'):
-			from .State import State
-			self._state = State(self._core, self._cmd_group)
+			from .State import StateCls
+			self._state = StateCls(self._core, self._cmd_group)
 		return self._state
 
 	@property
 	def spacing(self):
 		"""spacing commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_spacing'):
-			from .Spacing import Spacing
-			self._spacing = Spacing(self._core, self._cmd_group)
+			from .Spacing import SpacingCls
+			self._spacing = SpacingCls(self._core, self._cmd_group)
 		return self._spacing
 
-	def clone(self) -> 'McPhase':
+	def clone(self) -> 'McPhaseCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = McPhase(self._core, self._cmd_group.parent)
+		new_group = McPhaseCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
