@@ -3,7 +3,7 @@ from ........Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Magnitude:
+class MagnitudeCls:
 	"""Magnitude commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Magnitude:
 	def typePy(self):
 		"""typePy commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_typePy'):
-			from .TypePy import TypePy
-			self._typePy = TypePy(self._core, self._cmd_group)
+			from .TypePy import TypePyCls
+			self._typePy = TypePyCls(self._core, self._cmd_group)
 		return self._typePy
 
-	def clone(self) -> 'Magnitude':
+	def clone(self) -> 'MagnitudeCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Magnitude(self._core, self._cmd_group.parent)
+		new_group = MagnitudeCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
