@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Spectrum:
+class SpectrumCls:
 	"""Spectrum commands group definition. 5 total commands, 3 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,30 +14,30 @@ class Spectrum:
 	def magnitude(self):
 		"""magnitude commands group. 1 Sub-classes, 0 commands."""
 		if not hasattr(self, '_magnitude'):
-			from .Magnitude import Magnitude
-			self._magnitude = Magnitude(self._core, self._cmd_group)
+			from .Magnitude import MagnitudeCls
+			self._magnitude = MagnitudeCls(self._core, self._cmd_group)
 		return self._magnitude
 
 	@property
 	def phase(self):
 		"""phase commands group. 1 Sub-classes, 0 commands."""
 		if not hasattr(self, '_phase'):
-			from .Phase import Phase
-			self._phase = Phase(self._core, self._cmd_group)
+			from .Phase import PhaseCls
+			self._phase = PhaseCls(self._core, self._cmd_group)
 		return self._phase
 
 	@property
 	def span(self):
 		"""span commands group. 2 Sub-classes, 1 commands."""
 		if not hasattr(self, '_span'):
-			from .Span import Span
-			self._span = Span(self._core, self._cmd_group)
+			from .Span import SpanCls
+			self._span = SpanCls(self._core, self._cmd_group)
 		return self._span
 
-	def clone(self) -> 'Spectrum':
+	def clone(self) -> 'SpectrumCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Spectrum(self._core, self._cmd_group.parent)
+		new_group = SpectrumCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
