@@ -3,7 +3,7 @@ from ......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Adjust:
+class AdjustCls:
 	"""Adjust commands group definition. 5 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class Adjust:
 	def level(self):
 		"""level commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_level'):
-			from .Level import Level
-			self._level = Level(self._core, self._cmd_group)
+			from .Level import LevelCls
+			self._level = LevelCls(self._core, self._cmd_group)
 		return self._level
 
 	@property
 	def configure(self):
 		"""configure commands group. 2 Sub-classes, 0 commands."""
 		if not hasattr(self, '_configure'):
-			from .Configure import Configure
-			self._configure = Configure(self._core, self._cmd_group)
+			from .Configure import ConfigureCls
+			self._configure = ConfigureCls(self._core, self._cmd_group)
 		return self._configure
 
-	def clone(self) -> 'Adjust':
+	def clone(self) -> 'AdjustCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Adjust(self._core, self._cmd_group.parent)
+		new_group = AdjustCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
