@@ -3,7 +3,7 @@ from ......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Bandwidth:
+class BandwidthCls:
 	"""Bandwidth commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Bandwidth:
 	def demod(self):
 		"""demod commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_demod'):
-			from .Demod import Demod
-			self._demod = Demod(self._core, self._cmd_group)
+			from .Demod import DemodCls
+			self._demod = DemodCls(self._core, self._cmd_group)
 		return self._demod
 
-	def clone(self) -> 'Bandwidth':
+	def clone(self) -> 'BandwidthCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Bandwidth(self._core, self._cmd_group.parent)
+		new_group = BandwidthCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
