@@ -3,7 +3,7 @@ from ......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Carrier:
+class CarrierCls:
 	"""Carrier commands group definition. 3 total commands, 3 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,30 +14,30 @@ class Carrier:
 	def count(self):
 		"""count commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_count'):
-			from .Count import Count
-			self._count = Count(self._core, self._cmd_group)
+			from .Count import CountCls
+			self._count = CountCls(self._core, self._cmd_group)
 		return self._count
 
 	@property
 	def offset(self):
 		"""offset commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_offset'):
-			from .Offset import Offset
-			self._offset = Offset(self._core, self._cmd_group)
+			from .Offset import OffsetCls
+			self._offset = OffsetCls(self._core, self._cmd_group)
 		return self._offset
 
 	@property
 	def spacing(self):
 		"""spacing commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_spacing'):
-			from .Spacing import Spacing
-			self._spacing = Spacing(self._core, self._cmd_group)
+			from .Spacing import SpacingCls
+			self._spacing = SpacingCls(self._core, self._cmd_group)
 		return self._spacing
 
-	def clone(self) -> 'Carrier':
+	def clone(self) -> 'CarrierCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Carrier(self._core, self._cmd_group.parent)
+		new_group = CarrierCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
