@@ -3,7 +3,7 @@ from ......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class AmPm:
+class AmPmCls:
 	"""AmPm commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class AmPm:
 	def definition(self):
 		"""definition commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_definition'):
-			from .Definition import Definition
-			self._definition = Definition(self._core, self._cmd_group)
+			from .Definition import DefinitionCls
+			self._definition = DefinitionCls(self._core, self._cmd_group)
 		return self._definition
 
-	def clone(self) -> 'AmPm':
+	def clone(self) -> 'AmPmCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = AmPm(self._core, self._cmd_group.parent)
+		new_group = AmPmCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
