@@ -3,7 +3,7 @@ from ......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Gain:
+class GainCls:
 	"""Gain commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Gain:
 	def x(self):
 		"""x commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_x'):
-			from .X import X
-			self._x = X(self._core, self._cmd_group)
+			from .X import XCls
+			self._x = XCls(self._core, self._cmd_group)
 		return self._x
 
-	def clone(self) -> 'Gain':
+	def clone(self) -> 'GainCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Gain(self._core, self._cmd_group.parent)
+		new_group = GainCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
