@@ -4,7 +4,7 @@ from ....... import repcap
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Left:
+class LeftCls:
 	"""Left commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,7 +14,7 @@ class Left:
 	def set(self, window=repcap.Window.Default, marker=repcap.Marker.Default, opc_timeout_ms: int = -1) -> None:
 		"""SCPI: CALCulate<n>:MARKer<m>:MAXimum:LEFT \n
 		Snippet: driver.applications.k18AmplifierEt.calculate.marker.maximum.left.set(window = repcap.Window.Default, marker = repcap.Marker.Default) \n
-		This command moves a marker to the next lower peak. The search includes only measurement values to the left of the
+		This command moves a marker to the next positive peak. The search includes only measurement values to the left of the
 		current marker position. \n
 			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
 			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
