@@ -3,7 +3,7 @@ from ......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Mdpd:
+class MdpdCls:
 	"""Mdpd commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Mdpd:
 	def model(self):
 		"""model commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_model'):
-			from .Model import Model
-			self._model = Model(self._core, self._cmd_group)
+			from .Model import ModelCls
+			self._model = ModelCls(self._core, self._cmd_group)
 		return self._model
 
-	def clone(self) -> 'Mdpd':
+	def clone(self) -> 'MdpdCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Mdpd(self._core, self._cmd_group.parent)
+		new_group = MdpdCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
