@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Level:
+class LevelCls:
 	"""Level commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Level:
 	def correction(self):
 		"""correction commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_correction'):
-			from .Correction import Correction
-			self._correction = Correction(self._core, self._cmd_group)
+			from .Correction import CorrectionCls
+			self._correction = CorrectionCls(self._core, self._cmd_group)
 		return self._correction
 
-	def clone(self) -> 'Level':
+	def clone(self) -> 'LevelCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Level(self._core, self._cmd_group.parent)
+		new_group = LevelCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
