@@ -4,7 +4,7 @@ from .......Internal import Conversions
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Auto:
+class AutoCls:
 	"""Auto commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -15,7 +15,7 @@ class Auto:
 		"""SCPI: CONFigure:CFReduction:CSPacing:AUTO \n
 		Snippet: driver.applications.k18AmplifierEt.configure.cfReduction.cspacing.auto.set(state = False) \n
 		Sets and queries the crest factor reduction channel spacing mode. \n
-			:param state: 0 | 1 | OFF | ON
+			:param state: No help available
 		"""
 		param = Conversions.bool_to_str(state)
 		self._core.io.write(f'CONFigure:CFReduction:CSPacing:AUTO {param}')
@@ -24,6 +24,6 @@ class Auto:
 		"""SCPI: CONFigure:CFReduction:CSPacing:AUTO \n
 		Snippet: value: bool = driver.applications.k18AmplifierEt.configure.cfReduction.cspacing.auto.get() \n
 		Sets and queries the crest factor reduction channel spacing mode. \n
-			:return: state: 0 | 1 | OFF | ON"""
+			:return: state: No help available"""
 		response = self._core.io.query_str(f'CONFigure:CFReduction:CSPacing:AUTO?')
 		return Conversions.str_to_bool(response)
