@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Iterations:
+class IterationsCls:
 	"""Iterations commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Iterations:
 	def ledState(self):
 		"""ledState commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_ledState'):
-			from .LedState import LedState
-			self._ledState = LedState(self._core, self._cmd_group)
+			from .LedState import LedStateCls
+			self._ledState = LedStateCls(self._core, self._cmd_group)
 		return self._ledState
 
-	def clone(self) -> 'Iterations':
+	def clone(self) -> 'IterationsCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Iterations(self._core, self._cmd_group.parent)
+		new_group = IterationsCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
