@@ -4,7 +4,7 @@ from ......Internal import Conversions
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class RsOrignal:
+class RsOrignalCls:
 	"""RsOrignal commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -15,7 +15,7 @@ class RsOrignal:
 		"""SCPI: CONFigure:CFReduction:RSORignal \n
 		Snippet: driver.applications.k18AmplifierEt.configure.cfReduction.rsOrignal.set(state = False) \n
 		Switches the EVM reference signal. \n
-			:param state: 0 | 1 | OFF | ON
+			:param state: No help available
 		"""
 		param = Conversions.bool_to_str(state)
 		self._core.io.write(f'CONFigure:CFReduction:RSORignal {param}')
@@ -24,6 +24,6 @@ class RsOrignal:
 		"""SCPI: CONFigure:CFReduction:RSORignal \n
 		Snippet: value: bool = driver.applications.k18AmplifierEt.configure.cfReduction.rsOrignal.get() \n
 		Switches the EVM reference signal. \n
-			:return: state: 0 | 1 | OFF | ON"""
+			:return: state: No help available"""
 		response = self._core.io.query_str(f'CONFigure:CFReduction:RSORignal?')
 		return Conversions.str_to_bool(response)
