@@ -4,7 +4,7 @@ from ........Internal import Conversions
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class State:
+class StateCls:
 	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,8 +14,9 @@ class State:
 	def set(self, state: bool) -> None:
 		"""SCPI: CONFigure:DDPD:APPLy:WRAP[:STATe] \n
 		Snippet: driver.applications.k18AmplifierEt.configure.ddpd.apply.wrap.state.set(state = False) \n
-		No command help available \n
-			:param state: No help available
+		Smoothes start- and tail-samples down to '0' in order to avoid phase discontinuities when the file is cyclically played
+		from a signal source. \n
+			:param state: ON | OFF | 1 | 0
 		"""
 		param = Conversions.bool_to_str(state)
 		self._core.io.write(f'CONFigure:DDPD:APPLy:WRAP:STATe {param}')
@@ -23,7 +24,8 @@ class State:
 	def get(self) -> bool:
 		"""SCPI: CONFigure:DDPD:APPLy:WRAP[:STATe] \n
 		Snippet: value: bool = driver.applications.k18AmplifierEt.configure.ddpd.apply.wrap.state.get() \n
-		No command help available \n
-			:return: state: No help available"""
+		Smoothes start- and tail-samples down to '0' in order to avoid phase discontinuities when the file is cyclically played
+		from a signal source. \n
+			:return: state: ON | OFF | 1 | 0"""
 		response = self._core.io.query_str(f'CONFigure:DDPD:APPLy:WRAP:STATe?')
 		return Conversions.str_to_bool(response)
