@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Apply:
+class ApplyCls:
 	"""Apply commands group definition. 2 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class Apply:
 	def state(self):
 		"""state commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_state'):
-			from .State import State
-			self._state = State(self._core, self._cmd_group)
+			from .State import StateCls
+			self._state = StateCls(self._core, self._cmd_group)
 		return self._state
 
 	@property
 	def wrap(self):
 		"""wrap commands group. 1 Sub-classes, 0 commands."""
 		if not hasattr(self, '_wrap'):
-			from .Wrap import Wrap
-			self._wrap = Wrap(self._core, self._cmd_group)
+			from .Wrap import WrapCls
+			self._wrap = WrapCls(self._core, self._cmd_group)
 		return self._wrap
 
-	def clone(self) -> 'Apply':
+	def clone(self) -> 'ApplyCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Apply(self._core, self._cmd_group.parent)
+		new_group = ApplyCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
