@@ -4,7 +4,7 @@ from .......Internal import Conversions
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Current:
+class CurrentCls:
 	"""Current commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,7 +14,7 @@ class Current:
 	def get(self) -> float:
 		"""SCPI: CONFigure:DDPD:RMS[:CURRent] \n
 		Snippet: value: float = driver.applications.k18AmplifierEt.configure.ddpd.rms.current.get() \n
-		No command help available \n
-			:return: level: No help available"""
+		Returns the current RMS power level in manual direct DPD mode. \n
+			:return: level: numeric value"""
 		response = self._core.io.query_str(f'CONFigure:DDPD:RMS:CURRent?')
 		return Conversions.str_to_float(response)
