@@ -4,7 +4,7 @@ from .......Internal import Conversions
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class State:
+class StateCls:
 	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,7 +14,7 @@ class State:
 	def set(self, state: bool) -> None:
 		"""SCPI: CONFigure:DPD:AMPM[:STATe] \n
 		Snippet: driver.applications.k18AmplifierEt.configure.dpd.amPm.state.set(state = False) \n
-		This command turns AM/PM predistortion on and off.
+		This command turns 'AM/PM' predistortion on and off.
 			INTRO_CMD_HELP: Prerequisites for this command \n
 			- Turn on polynomial DPD (method RsFsw.Applications.K18_AmplifierEt.Configure.Ddpd.State.set) . \n
 			:param state: ON | OFF | 1 | 0
@@ -25,7 +25,7 @@ class State:
 	def get(self) -> bool:
 		"""SCPI: CONFigure:DPD:AMPM[:STATe] \n
 		Snippet: value: bool = driver.applications.k18AmplifierEt.configure.dpd.amPm.state.get() \n
-		This command turns AM/PM predistortion on and off.
+		This command turns 'AM/PM' predistortion on and off.
 			INTRO_CMD_HELP: Prerequisites for this command \n
 			- Turn on polynomial DPD (method RsFsw.Applications.K18_AmplifierEt.Configure.Ddpd.State.set) . \n
 			:return: state: ON | OFF | 1 | 0"""
