@@ -5,7 +5,7 @@ from ....... import enums
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class LedState:
+class LedStateCls:
 	"""LedState commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -16,7 +16,7 @@ class LedState:
 	def get(self) -> enums.LedState:
 		"""SCPI: CONFigure:DPD:AMAM:LEDState \n
 		Snippet: value: enums.LedState = driver.applications.k18AmplifierEt.configure.dpd.amam.ledState.get() \n
-		This command queries the state of the calculation of the AM/AM distortion curve. \n
+		This command queries the state of the calculation of the 'AM/AM' distortion curve. \n
 			:return: state: GREen Calculation was successful. GREY Unknown calculation state. RED Calculation was not successful."""
 		response = self._core.io.query_str(f'CONFigure:DPD:AMAM:LEDState?')
 		return Conversions.str_to_scalar_enum(response, enums.LedState)
