@@ -4,7 +4,7 @@ from .......Internal import Conversions
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class State:
+class StateCls:
 	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,7 +14,7 @@ class State:
 	def set(self, state: bool) -> None:
 		"""SCPI: CONFigure:DPD:AMXM[:STATe] \n
 		Snippet: driver.applications.k18AmplifierEt.configure.dpd.amxm.state.set(state = False) \n
-		This command turns AM/AM and AM/PM predistortion on and off (at the same time) .
+		This command turns 'AM/AM' and 'AM/PM' predistortion on and off (at the same time) .
 			INTRO_CMD_HELP: Alternatively, you can do that with: \n
 			- method RsFsw.Applications.K18_AmplifierEt.Configure.Dpd.Amam.State.set and
 			- method RsFsw.Applications.K18_AmplifierEt.Configure.Dpd.AmPm.State.set
