@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class File:
+class FileCls:
 	"""File commands group definition. 2 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class File:
 	def generate(self):
 		"""generate commands group. 1 Sub-classes, 1 commands."""
 		if not hasattr(self, '_generate'):
-			from .Generate import Generate
-			self._generate = Generate(self._core, self._cmd_group)
+			from .Generate import GenerateCls
+			self._generate = GenerateCls(self._core, self._cmd_group)
 		return self._generate
 
-	def clone(self) -> 'File':
+	def clone(self) -> 'FileCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = File(self._core, self._cmd_group.parent)
+		new_group = FileCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
