@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class FilterPy:
+class FilterPyCls:
 	"""FilterPy commands group definition. 2 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class FilterPy:
 	def file(self):
 		"""file commands group. 1 Sub-classes, 0 commands."""
 		if not hasattr(self, '_file'):
-			from .File import File
-			self._file = File(self._core, self._cmd_group)
+			from .File import FileCls
+			self._file = FileCls(self._core, self._cmd_group)
 		return self._file
 
 	@property
 	def length(self):
 		"""length commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_length'):
-			from .Length import Length
-			self._length = Length(self._core, self._cmd_group)
+			from .Length import LengthCls
+			self._length = LengthCls(self._core, self._cmd_group)
 		return self._length
 
-	def clone(self) -> 'FilterPy':
+	def clone(self) -> 'FilterPyCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = FilterPy(self._core, self._cmd_group.parent)
+		new_group = FilterPyCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
