@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class External:
+class ExternalCls:
 	"""External commands group definition. 2 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class External:
 	def roscillator(self):
 		"""roscillator commands group. 1 Sub-classes, 1 commands."""
 		if not hasattr(self, '_roscillator'):
-			from .Roscillator import Roscillator
-			self._roscillator = Roscillator(self._core, self._cmd_group)
+			from .Roscillator import RoscillatorCls
+			self._roscillator = RoscillatorCls(self._core, self._cmd_group)
 		return self._roscillator
 
-	def clone(self) -> 'External':
+	def clone(self) -> 'ExternalCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = External(self._core, self._cmd_group.parent)
+		new_group = ExternalCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
