@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Level:
+class LevelCls:
 	"""Level commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Level:
 	def dutLimit(self):
 		"""dutLimit commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_dutLimit'):
-			from .DutLimit import DutLimit
-			self._dutLimit = DutLimit(self._core, self._cmd_group)
+			from .DutLimit import DutLimitCls
+			self._dutLimit = DutLimitCls(self._core, self._cmd_group)
 		return self._dutLimit
 
-	def clone(self) -> 'Level':
+	def clone(self) -> 'LevelCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Level(self._core, self._cmd_group.parent)
+		new_group = LevelCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
