@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Power:
+class PowerCls:
 	"""Power commands group definition. 7 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class Power:
 	def level(self):
 		"""level commands group. 3 Sub-classes, 1 commands."""
 		if not hasattr(self, '_level'):
-			from .Level import Level
-			self._level = Level(self._core, self._cmd_group)
+			from .Level import LevelCls
+			self._level = LevelCls(self._core, self._cmd_group)
 		return self._level
 
 	@property
 	def ppow(self):
 		"""ppow commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_ppow'):
-			from .Ppow import Ppow
-			self._ppow = Ppow(self._core, self._cmd_group)
+			from .Ppow import PpowCls
+			self._ppow = PpowCls(self._core, self._cmd_group)
 		return self._ppow
 
-	def clone(self) -> 'Power':
+	def clone(self) -> 'PowerCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Power(self._core, self._cmd_group.parent)
+		new_group = PowerCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
