@@ -3,7 +3,7 @@ from ........Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Path:
+class PathCls:
 	"""Path commands group definition. 2 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class Path:
 	def bb(self):
 		"""bb commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_bb'):
-			from .Bb import Bb
-			self._bb = Bb(self._core, self._cmd_group)
+			from .Bb import BbCls
+			self._bb = BbCls(self._core, self._cmd_group)
 		return self._bb
 
 	@property
 	def rf(self):
 		"""rf commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_rf'):
-			from .Rf import Rf
-			self._rf = Rf(self._core, self._cmd_group)
+			from .Rf import RfCls
+			self._rf = RfCls(self._core, self._cmd_group)
 		return self._rf
 
-	def clone(self) -> 'Path':
+	def clone(self) -> 'PathCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Path(self._core, self._cmd_group.parent)
+		new_group = PathCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
