@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Target:
+class TargetCls:
 	"""Target commands group definition. 2 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Target:
 	def path(self):
 		"""path commands group. 2 Sub-classes, 0 commands."""
 		if not hasattr(self, '_path'):
-			from .Path import Path
-			self._path = Path(self._core, self._cmd_group)
+			from .Path import PathCls
+			self._path = PathCls(self._core, self._cmd_group)
 		return self._path
 
-	def clone(self) -> 'Target':
+	def clone(self) -> 'TargetCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Target(self._core, self._cmd_group.parent)
+		new_group = TargetCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
