@@ -3,7 +3,7 @@ from ........Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Parameter:
+class ParameterCls:
 	"""Parameter commands group definition. 2 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class Parameter:
 	def a(self):
 		"""a commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_a'):
-			from .A import A
-			self._a = A(self._core, self._cmd_group)
+			from .A import ACls
+			self._a = ACls(self._core, self._cmd_group)
 		return self._a
 
 	@property
 	def b(self):
 		"""b commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_b'):
-			from .B import B
-			self._b = B(self._core, self._cmd_group)
+			from .B import BCls
+			self._b = BCls(self._core, self._cmd_group)
 		return self._b
 
-	def clone(self) -> 'Parameter':
+	def clone(self) -> 'ParameterCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Parameter(self._core, self._cmd_group.parent)
+		new_group = ParameterCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
