@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Qchannel:
+class QchannelCls:
 	"""Qchannel commands group definition. 2 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class Qchannel:
 	def multiplier(self):
 		"""multiplier commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_multiplier'):
-			from .Multiplier import Multiplier
-			self._multiplier = Multiplier(self._core, self._cmd_group)
+			from .Multiplier import MultiplierCls
+			self._multiplier = MultiplierCls(self._core, self._cmd_group)
 		return self._multiplier
 
 	@property
 	def offset(self):
 		"""offset commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_offset'):
-			from .Offset import Offset
-			self._offset = Offset(self._core, self._cmd_group)
+			from .Offset import OffsetCls
+			self._offset = OffsetCls(self._core, self._cmd_group)
 		return self._offset
 
-	def clone(self) -> 'Qchannel':
+	def clone(self) -> 'QchannelCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Qchannel(self._core, self._cmd_group.parent)
+		new_group = QchannelCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
