@@ -3,7 +3,7 @@ from ........Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class P3Db:
+class P3DbCls:
 	"""P3Db commands group definition. 2 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class P3Db:
 	def state(self):
 		"""state commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_state'):
-			from .State import State
-			self._state = State(self._core, self._cmd_group)
+			from .State import StateCls
+			self._state = StateCls(self._core, self._cmd_group)
 		return self._state
 
 	@property
 	def reference(self):
 		"""reference commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_reference'):
-			from .Reference import Reference
-			self._reference = Reference(self._core, self._cmd_group)
+			from .Reference import ReferenceCls
+			self._reference = ReferenceCls(self._core, self._cmd_group)
 		return self._reference
 
-	def clone(self) -> 'P3Db':
+	def clone(self) -> 'P3DbCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = P3Db(self._core, self._cmd_group.parent)
+		new_group = P3DbCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
