@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Result:
+class ResultCls:
 	"""Result commands group definition. 2 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Result:
 	def p3Db(self):
 		"""p3Db commands group. 2 Sub-classes, 0 commands."""
 		if not hasattr(self, '_p3Db'):
-			from .P3Db import P3Db
-			self._p3Db = P3Db(self._core, self._cmd_group)
+			from .P3Db import P3DbCls
+			self._p3Db = P3DbCls(self._core, self._cmd_group)
 		return self._p3Db
 
-	def clone(self) -> 'Result':
+	def clone(self) -> 'ResultCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Result(self._core, self._cmd_group.parent)
+		new_group = ResultCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
