@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Expected:
+class ExpectedCls:
 	"""Expected commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Expected:
 	def gain(self):
 		"""gain commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_gain'):
-			from .Gain import Gain
-			self._gain = Gain(self._core, self._cmd_group)
+			from .Gain import GainCls
+			self._gain = GainCls(self._core, self._cmd_group)
 		return self._gain
 
-	def clone(self) -> 'Expected':
+	def clone(self) -> 'ExpectedCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Expected(self._core, self._cmd_group.parent)
+		new_group = ExpectedCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
