@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Range:
+class RangeCls:
 	"""Range commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Range:
 	def selected(self):
 		"""selected commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_selected'):
-			from .Selected import Selected
-			self._selected = Selected(self._core, self._cmd_group)
+			from .Selected import SelectedCls
+			self._selected = SelectedCls(self._core, self._cmd_group)
 		return self._selected
 
-	def clone(self) -> 'Range':
+	def clone(self) -> 'RangeCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Range(self._core, self._cmd_group.parent)
+		new_group = RangeCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
