@@ -3,7 +3,7 @@ from ......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Signal:
+class SignalCls:
 	"""Signal commands group definition. 10 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Signal:
 	def error(self):
 		"""error commands group. 2 Sub-classes, 0 commands."""
 		if not hasattr(self, '_error'):
-			from .Error import Error
-			self._error = Error(self._core, self._cmd_group)
+			from .Error import ErrorCls
+			self._error = ErrorCls(self._core, self._cmd_group)
 		return self._error
 
-	def clone(self) -> 'Signal':
+	def clone(self) -> 'SignalCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Signal(self._core, self._cmd_group.parent)
+		new_group = SignalCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
