@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Psweep:
+class PsweepCls:
 	"""Psweep commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Psweep:
 	def range(self):
 		"""range commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_range'):
-			from .Range import Range
-			self._range = Range(self._core, self._cmd_group)
+			from .Range import RangeCls
+			self._range = RangeCls(self._core, self._cmd_group)
 		return self._range
 
-	def clone(self) -> 'Psweep':
+	def clone(self) -> 'PsweepCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Psweep(self._core, self._cmd_group.parent)
+		new_group = PsweepCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
