@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Ptable:
+class PtableCls:
 	"""Ptable commands group definition. 2 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Ptable:
 	def item(self):
 		"""item commands group. 1 Sub-classes, 1 commands."""
 		if not hasattr(self, '_item'):
-			from .Item import Item
-			self._item = Item(self._core, self._cmd_group)
+			from .Item import ItemCls
+			self._item = ItemCls(self._core, self._cmd_group)
 		return self._item
 
-	def clone(self) -> 'Ptable':
+	def clone(self) -> 'PtableCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Ptable(self._core, self._cmd_group.parent)
+		new_group = PtableCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
