@@ -3,7 +3,7 @@ from .........Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Scale:
+class ScaleCls:
 	"""Scale commands group definition. 3 total commands, 3 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,30 +14,30 @@ class Scale:
 	def duration(self):
 		"""duration commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_duration'):
-			from .Duration import Duration
-			self._duration = Duration(self._core, self._cmd_group)
+			from .Duration import DurationCls
+			self._duration = DurationCls(self._core, self._cmd_group)
 		return self._duration
 
 	@property
 	def mode(self):
 		"""mode commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_mode'):
-			from .Mode import Mode
-			self._mode = Mode(self._core, self._cmd_group)
+			from .Mode import ModeCls
+			self._mode = ModeCls(self._core, self._cmd_group)
 		return self._mode
 
 	@property
 	def offset(self):
 		"""offset commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_offset'):
-			from .Offset import Offset
-			self._offset = Offset(self._core, self._cmd_group)
+			from .Offset import OffsetCls
+			self._offset = OffsetCls(self._core, self._cmd_group)
 		return self._offset
 
-	def clone(self) -> 'Scale':
+	def clone(self) -> 'ScaleCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Scale(self._core, self._cmd_group.parent)
+		new_group = ScaleCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
