@@ -3,7 +3,7 @@ from .........Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Scale:
+class ScaleCls:
 	"""Scale commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Scale:
 	def normalise(self):
 		"""normalise commands group. 1 Sub-classes, 0 commands."""
 		if not hasattr(self, '_normalise'):
-			from .Normalise import Normalise
-			self._normalise = Normalise(self._core, self._cmd_group)
+			from .Normalise import NormaliseCls
+			self._normalise = NormaliseCls(self._core, self._cmd_group)
 		return self._normalise
 
-	def clone(self) -> 'Scale':
+	def clone(self) -> 'ScaleCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Scale(self._core, self._cmd_group.parent)
+		new_group = ScaleCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
