@@ -3,7 +3,7 @@ from .....Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Display:
+class DisplayCls:
 	"""Display commands group definition. 37 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class Display:
 	def window(self):
 		"""window commands group. 11 Sub-classes, 0 commands."""
 		if not hasattr(self, '_window'):
-			from .Window import Window
-			self._window = Window(self._core, self._cmd_group)
+			from .Window import WindowCls
+			self._window = WindowCls(self._core, self._cmd_group)
 		return self._window
 
 	@property
 	def wselect(self):
 		"""wselect commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_wselect'):
-			from .Wselect import Wselect
-			self._wselect = Wselect(self._core, self._cmd_group)
+			from .Wselect import WselectCls
+			self._wselect = WselectCls(self._core, self._cmd_group)
 		return self._wselect
 
-	def clone(self) -> 'Display':
+	def clone(self) -> 'DisplayCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Display(self._core, self._cmd_group.parent)
+		new_group = DisplayCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
