@@ -4,7 +4,7 @@ from ........Internal import Conversions
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Result:
+class ResultCls:
 	"""Result commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,7 +14,7 @@ class Result:
 	def get(self) -> float:
 		"""SCPI: FETCh:AMPM:CWIDth:CURRent[:RESult] \n
 		Snippet: value: float = driver.applications.k18AmplifierEt.fetch.amPm.cwidth.current.result.get() \n
-		This command queries the AM/PM Curve Width as shown in the Result Summary. \n
-			:return: curve_width: numeric value Current AM/PM Curve Width. Unit: degree"""
+		This command queries the 'AM/PM' Curve Width as shown in the Result Summary. \n
+			:return: curve_width: numeric value Current 'AM/PM' Curve Width. Unit: degree"""
 		response = self._core.io.query_str(f'FETCh:AMPM:CWIDth:CURRent:RESult?')
 		return Conversions.str_to_float(response)
