@@ -3,8 +3,8 @@ from ......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class AmPm:
-	"""AmPm commands group definition. 3 total commands, 1 Subgroups, 0 group commands"""
+class AmPmCls:
+	"""AmPm commands group definition. 6 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
 		self._core = core
@@ -14,14 +14,22 @@ class AmPm:
 	def cwidth(self):
 		"""cwidth commands group. 3 Sub-classes, 0 commands."""
 		if not hasattr(self, '_cwidth'):
-			from .Cwidth import Cwidth
-			self._cwidth = Cwidth(self._core, self._cmd_group)
+			from .Cwidth import CwidthCls
+			self._cwidth = CwidthCls(self._core, self._cmd_group)
 		return self._cwidth
 
-	def clone(self) -> 'AmPm':
+	@property
+	def peak(self):
+		"""peak commands group. 1 Sub-classes, 0 commands."""
+		if not hasattr(self, '_peak'):
+			from .Peak import PeakCls
+			self._peak = PeakCls(self._core, self._cmd_group)
+		return self._peak
+
+	def clone(self) -> 'AmPmCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = AmPm(self._core, self._cmd_group.parent)
+		new_group = AmPmCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
