@@ -3,8 +3,8 @@ from ......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Dpd:
-	"""Dpd commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
+class DpdCls:
+	"""Dpd commands group definition. 2 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
 		self._core = core
@@ -14,14 +14,22 @@ class Dpd:
 	def polynomial(self):
 		"""polynomial commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_polynomial'):
-			from .Polynomial import Polynomial
-			self._polynomial = Polynomial(self._core, self._cmd_group)
+			from .Polynomial import PolynomialCls
+			self._polynomial = PolynomialCls(self._core, self._cmd_group)
 		return self._polynomial
 
-	def clone(self) -> 'Dpd':
+	@property
+	def waveform(self):
+		"""waveform commands group. 1 Sub-classes, 0 commands."""
+		if not hasattr(self, '_waveform'):
+			from .Waveform import WaveformCls
+			self._waveform = WaveformCls(self._core, self._cmd_group)
+		return self._waveform
+
+	def clone(self) -> 'DpdCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Dpd(self._core, self._cmd_group.parent)
+		new_group = DpdCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
