@@ -3,7 +3,7 @@ from ......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Ivoltage:
+class IvoltageCls:
 	"""Ivoltage commands group definition. 3 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Ivoltage:
 	def pure(self):
 		"""pure commands group. 3 Sub-classes, 0 commands."""
 		if not hasattr(self, '_pure'):
-			from .Pure import Pure
-			self._pure = Pure(self._core, self._cmd_group)
+			from .Pure import PureCls
+			self._pure = PureCls(self._core, self._cmd_group)
 		return self._pure
 
-	def clone(self) -> 'Ivoltage':
+	def clone(self) -> 'IvoltageCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Ivoltage(self._core, self._cmd_group.parent)
+		new_group = IvoltageCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
