@@ -4,7 +4,7 @@ from ........Internal import Conversions
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Result:
+class ResultCls:
 	"""Result commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,7 +14,7 @@ class Result:
 	def get(self) -> float:
 		"""SCPI: FETCh:MACCuracy:REVM:MINimum[:RESult] \n
 		Snippet: value: float = driver.applications.k18AmplifierEt.fetch.maccuracy.revm.minimum.result.get() \n
-		This command queries the Raw EVM as shown in the Result Summary. \n
-			:return: evm: numeric value Minimum, maximum or current Raw EVM, depending on the command syntax. Unit: %"""
+		This command queries the 'Raw EVM' as shown in the Result Summary. \n
+			:return: evm: numeric value Minimum, maximum or current 'Raw EVM', depending on the command syntax. Unit: %"""
 		response = self._core.io.query_str(f'FETCh:MACCuracy:REVM:MINimum:RESult?')
 		return Conversions.str_to_float(response)
