@@ -3,8 +3,8 @@ from ......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Mdpd:
-	"""Mdpd commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
+class MdpdCls:
+	"""Mdpd commands group definition. 2 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
 		self._core = core
@@ -14,14 +14,22 @@ class Mdpd:
 	def coefficients(self):
 		"""coefficients commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_coefficients'):
-			from .Coefficients import Coefficients
-			self._coefficients = Coefficients(self._core, self._cmd_group)
+			from .Coefficients import CoefficientsCls
+			self._coefficients = CoefficientsCls(self._core, self._cmd_group)
 		return self._coefficients
 
-	def clone(self) -> 'Mdpd':
+	@property
+	def waveform(self):
+		"""waveform commands group. 1 Sub-classes, 0 commands."""
+		if not hasattr(self, '_waveform'):
+			from .Waveform import WaveformCls
+			self._waveform = WaveformCls(self._core, self._cmd_group)
+		return self._waveform
+
+	def clone(self) -> 'MdpdCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Mdpd(self._core, self._cmd_group.parent)
+		new_group = MdpdCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
