@@ -3,7 +3,7 @@ from ......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Pc:
+class PcCls:
 	"""Pc commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Pc:
 	def current(self):
 		"""current commands group. 1 Sub-classes, 0 commands."""
 		if not hasattr(self, '_current'):
-			from .Current import Current
-			self._current = Current(self._core, self._cmd_group)
+			from .Current import CurrentCls
+			self._current = CurrentCls(self._core, self._cmd_group)
 		return self._current
 
-	def clone(self) -> 'Pc':
+	def clone(self) -> 'PcCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Pc(self._core, self._cmd_group.parent)
+		new_group = PcCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
