@@ -3,7 +3,7 @@ from .........Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Current:
+class CurrentCls:
 	"""Current commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Current:
 	def result(self):
 		"""result commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_result'):
-			from .Result import Result
-			self._result = Result(self._core, self._cmd_group)
+			from .Result import ResultCls
+			self._result = ResultCls(self._core, self._cmd_group)
 		return self._result
 
-	def clone(self) -> 'Current':
+	def clone(self) -> 'CurrentCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Current(self._core, self._cmd_group.parent)
+		new_group = CurrentCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
