@@ -3,7 +3,7 @@ from ........Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Achannel:
+class AchannelCls:
 	"""Achannel commands group definition. 18 total commands, 3 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,30 +14,30 @@ class Achannel:
 	def balanced(self):
 		"""balanced commands group. 2 Sub-classes, 0 commands."""
 		if not hasattr(self, '_balanced'):
-			from .Balanced import Balanced
-			self._balanced = Balanced(self._core, self._cmd_group)
+			from .Balanced import BalancedCls
+			self._balanced = BalancedCls(self._core, self._cmd_group)
 		return self._balanced
 
 	@property
 	def lower(self):
 		"""lower commands group. 2 Sub-classes, 0 commands."""
 		if not hasattr(self, '_lower'):
-			from .Lower import Lower
-			self._lower = Lower(self._core, self._cmd_group)
+			from .Lower import LowerCls
+			self._lower = LowerCls(self._core, self._cmd_group)
 		return self._lower
 
 	@property
 	def upper(self):
 		"""upper commands group. 2 Sub-classes, 0 commands."""
 		if not hasattr(self, '_upper'):
-			from .Upper import Upper
-			self._upper = Upper(self._core, self._cmd_group)
+			from .Upper import UpperCls
+			self._upper = UpperCls(self._core, self._cmd_group)
 		return self._upper
 
-	def clone(self) -> 'Achannel':
+	def clone(self) -> 'AchannelCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Achannel(self._core, self._cmd_group.parent)
+		new_group = AchannelCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
