@@ -4,7 +4,7 @@ from .........Internal import Conversions
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Result:
+class ResultCls:
 	"""Result commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,7 +14,8 @@ class Result:
 	def get(self) -> float:
 		"""SCPI: FETCh:PTABle:BBPower:MAXimum:X[:RESult] \n
 		Snippet: value: float = driver.applications.k18AmplifierEt.fetch.ptable.bbPower.maximum.x.result.get() \n
-		These commands query the result values for the Baseband Power (I_cc * V_cc) result as shown in the Parameter Sweep Table. \n
+		These commands query the result values for the Baseband Power (I_cc * V_cc) result as shown in the 'Parameter Sweep'
+		Table. \n
 			:return: results: numeric value • For ...[:RESult]: Minimum or maximum result that has been measured. • For ...:X[:RESult]: Location on the x-axis where the minimum or maximum result has been measured. The type of value depends on the parameter you have selected for the x-axis (method RsFsw.Applications.K18_AmplifierEt.Configure.Psweep.X.Setting.set) . • For ...:Y[:RESult]: Location on the y-axis where the minimum or maximum result has been measured. The type of value depends on the parameter you have selected for the y-axis (method RsFsw.Applications.K18_AmplifierEt.Configure.Psweep.Y.Setting.set) ."""
 		response = self._core.io.query_str(f'FETCh:PTABle:BBPower:MAXimum:X:RESult?')
 		return Conversions.str_to_float(response)
