@@ -5,7 +5,7 @@ from ......... import enums
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class StDeviation:
+class StDeviationCls:
 	"""StDeviation commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
