@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Power:
+class PowerCls:
 	"""Power commands group definition. 30 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class Power:
 	def inputPy(self):
 		"""inputPy commands group. 3 Sub-classes, 0 commands."""
 		if not hasattr(self, '_inputPy'):
-			from .InputPy import InputPy
-			self._inputPy = InputPy(self._core, self._cmd_group)
+			from .InputPy import InputPyCls
+			self._inputPy = InputPyCls(self._core, self._cmd_group)
 		return self._inputPy
 
 	@property
 	def output(self):
 		"""output commands group. 3 Sub-classes, 0 commands."""
 		if not hasattr(self, '_output'):
-			from .Output import Output
-			self._output = Output(self._core, self._cmd_group)
+			from .Output import OutputCls
+			self._output = OutputCls(self._core, self._cmd_group)
 		return self._output
 
-	def clone(self) -> 'Power':
+	def clone(self) -> 'PowerCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Power(self._core, self._cmd_group.parent)
+		new_group = PowerCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
