@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Revm:
+class RevmCls:
 	"""Revm commands group definition. 15 total commands, 3 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,30 +14,30 @@ class Revm:
 	def avg(self):
 		"""avg commands group. 5 Sub-classes, 0 commands."""
 		if not hasattr(self, '_avg'):
-			from .Avg import Avg
-			self._avg = Avg(self._core, self._cmd_group)
+			from .Avg import AvgCls
+			self._avg = AvgCls(self._core, self._cmd_group)
 		return self._avg
 
 	@property
 	def max(self):
 		"""max commands group. 5 Sub-classes, 0 commands."""
 		if not hasattr(self, '_max'):
-			from .Max import Max
-			self._max = Max(self._core, self._cmd_group)
+			from .Max import MaxCls
+			self._max = MaxCls(self._core, self._cmd_group)
 		return self._max
 
 	@property
 	def min(self):
 		"""min commands group. 5 Sub-classes, 0 commands."""
 		if not hasattr(self, '_min'):
-			from .Min import Min
-			self._min = Min(self._core, self._cmd_group)
+			from .Min import MinCls
+			self._min = MinCls(self._core, self._cmd_group)
 		return self._min
 
-	def clone(self) -> 'Revm':
+	def clone(self) -> 'RevmCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Revm(self._core, self._cmd_group.parent)
+		new_group = RevmCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
