@@ -3,7 +3,7 @@ from ......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Sync:
+class SyncCls:
 	"""Sync commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Sync:
 	def fail(self):
 		"""fail commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_fail'):
-			from .Fail import Fail
-			self._fail = Fail(self._core, self._cmd_group)
+			from .Fail import FailCls
+			self._fail = FailCls(self._core, self._cmd_group)
 		return self._fail
 
-	def clone(self) -> 'Sync':
+	def clone(self) -> 'SyncCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Sync(self._core, self._cmd_group.parent)
+		new_group = SyncCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
