@@ -3,7 +3,7 @@ from ......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Iq:
+class IqCls:
 	"""Iq commands group definition. 2 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class Iq:
 	def balanced(self):
 		"""balanced commands group. 1 Sub-classes, 0 commands."""
 		if not hasattr(self, '_balanced'):
-			from .Balanced import Balanced
-			self._balanced = Balanced(self._core, self._cmd_group)
+			from .Balanced import BalancedCls
+			self._balanced = BalancedCls(self._core, self._cmd_group)
 		return self._balanced
 
 	@property
 	def fullscale(self):
 		"""fullscale commands group. 1 Sub-classes, 0 commands."""
 		if not hasattr(self, '_fullscale'):
-			from .Fullscale import Fullscale
-			self._fullscale = Fullscale(self._core, self._cmd_group)
+			from .Fullscale import FullscaleCls
+			self._fullscale = FullscaleCls(self._core, self._cmd_group)
 		return self._fullscale
 
-	def clone(self) -> 'Iq':
+	def clone(self) -> 'IqCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Iq(self._core, self._cmd_group.parent)
+		new_group = IqCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
