@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Equalizer:
+class EqualizerCls:
 	"""Equalizer commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Equalizer:
 	def filterPy(self):
 		"""filterPy commands group. 1 Sub-classes, 0 commands."""
 		if not hasattr(self, '_filterPy'):
-			from .FilterPy import FilterPy
-			self._filterPy = FilterPy(self._core, self._cmd_group)
+			from .FilterPy import FilterPyCls
+			self._filterPy = FilterPyCls(self._core, self._cmd_group)
 		return self._filterPy
 
-	def clone(self) -> 'Equalizer':
+	def clone(self) -> 'EqualizerCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Equalizer(self._core, self._cmd_group.parent)
+		new_group = EqualizerCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
