@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Mdpd:
+class MdpdCls:
 	"""Mdpd commands group definition. 2 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class Mdpd:
 	def coefficient(self):
 		"""coefficient commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_coefficient'):
-			from .Coefficient import Coefficient
-			self._coefficient = Coefficient(self._core, self._cmd_group)
+			from .Coefficient import CoefficientCls
+			self._coefficient = CoefficientCls(self._core, self._cmd_group)
 		return self._coefficient
 
 	@property
 	def waveform(self):
 		"""waveform commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_waveform'):
-			from .Waveform import Waveform
-			self._waveform = Waveform(self._core, self._cmd_group)
+			from .Waveform import WaveformCls
+			self._waveform = WaveformCls(self._core, self._cmd_group)
 		return self._waveform
 
-	def clone(self) -> 'Mdpd':
+	def clone(self) -> 'MdpdCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Mdpd(self._core, self._cmd_group.parent)
+		new_group = MdpdCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
