@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Time:
+class TimeCls:
 	"""Time commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Time:
 	def trigger(self):
 		"""trigger commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_trigger'):
-			from .Trigger import Trigger
-			self._trigger = Trigger(self._core, self._cmd_group)
+			from .Trigger import TriggerCls
+			self._trigger = TriggerCls(self._core, self._cmd_group)
 		return self._trigger
 
-	def clone(self) -> 'Time':
+	def clone(self) -> 'TimeCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Time(self._core, self._cmd_group.parent)
+		new_group = TimeCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
