@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Default:
+class DefaultCls:
 	"""Default commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Default:
 	def function(self):
 		"""function commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_function'):
-			from .Function import Function
-			self._function = Function(self._core, self._cmd_group)
+			from .Function import FunctionCls
+			self._function = FunctionCls(self._core, self._cmd_group)
 		return self._function
 
-	def clone(self) -> 'Default':
+	def clone(self) -> 'DefaultCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Default(self._core, self._cmd_group.parent)
+		new_group = DefaultCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
