@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Trace:
+class TraceCls:
 	"""Trace commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Trace:
 	def point(self):
 		"""point commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_point'):
-			from .Point import Point
-			self._point = Point(self._core, self._cmd_group)
+			from .Point import PointCls
+			self._point = PointCls(self._core, self._cmd_group)
 		return self._point
 
-	def clone(self) -> 'Trace':
+	def clone(self) -> 'TraceCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Trace(self._core, self._cmd_group.parent)
+		new_group = TraceCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
