@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Bias:
+class BiasCls:
 	"""Bias commands group definition. 2 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class Bias:
 	def low(self):
 		"""low commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_low'):
-			from .Low import Low
-			self._low = Low(self._core, self._cmd_group)
+			from .Low import LowCls
+			self._low = LowCls(self._core, self._cmd_group)
 		return self._low
 
 	@property
 	def high(self):
 		"""high commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_high'):
-			from .High import High
-			self._high = High(self._core, self._cmd_group)
+			from .High import HighCls
+			self._high = HighCls(self._core, self._cmd_group)
 		return self._high
 
-	def clone(self) -> 'Bias':
+	def clone(self) -> 'BiasCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Bias(self._core, self._cmd_group.parent)
+		new_group = BiasCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
