@@ -3,7 +3,7 @@ from ........Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Correction:
+class CorrectionCls:
 	"""Correction commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Correction:
 	def apply(self):
 		"""apply commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_apply'):
-			from .Apply import Apply
-			self._apply = Apply(self._core, self._cmd_group)
+			from .Apply import ApplyCls
+			self._apply = ApplyCls(self._core, self._cmd_group)
 		return self._apply
 
-	def clone(self) -> 'Correction':
+	def clone(self) -> 'CorrectionCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Correction(self._core, self._cmd_group.parent)
+		new_group = CorrectionCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
