@@ -3,7 +3,7 @@ from ........Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class FilterPy:
+class FilterPyCls:
 	"""FilterPy commands group definition. 6 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class FilterPy:
 	def alpha(self):
 		"""alpha commands group. 3 Sub-classes, 0 commands."""
 		if not hasattr(self, '_alpha'):
-			from .Alpha import Alpha
-			self._alpha = Alpha(self._core, self._cmd_group)
+			from .Alpha import AlphaCls
+			self._alpha = AlphaCls(self._core, self._cmd_group)
 		return self._alpha
 
 	@property
 	def state(self):
 		"""state commands group. 3 Sub-classes, 0 commands."""
 		if not hasattr(self, '_state'):
-			from .State import State
-			self._state = State(self._core, self._cmd_group)
+			from .State import StateCls
+			self._state = StateCls(self._core, self._cmd_group)
 		return self._state
 
-	def clone(self) -> 'FilterPy':
+	def clone(self) -> 'FilterPyCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = FilterPy(self._core, self._cmd_group.parent)
+		new_group = FilterPyCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
