@@ -3,7 +3,7 @@ from ......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Power:
+class PowerCls:
 	"""Power commands group definition. 15 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Power:
 	def achannel(self):
 		"""achannel commands group. 7 Sub-classes, 0 commands."""
 		if not hasattr(self, '_achannel'):
-			from .Achannel import Achannel
-			self._achannel = Achannel(self._core, self._cmd_group)
+			from .Achannel import AchannelCls
+			self._achannel = AchannelCls(self._core, self._cmd_group)
 		return self._achannel
 
-	def clone(self) -> 'Power':
+	def clone(self) -> 'PowerCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Power(self._core, self._cmd_group.parent)
+		new_group = PowerCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
