@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class IqAvg:
+class IqAvgCls:
 	"""IqAvg commands group definition. 4 total commands, 3 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,30 +14,30 @@ class IqAvg:
 	def state(self):
 		"""state commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_state'):
-			from .State import State
-			self._state = State(self._core, self._cmd_group)
+			from .State import StateCls
+			self._state = StateCls(self._core, self._cmd_group)
 		return self._state
 
 	@property
 	def count(self):
 		"""count commands group. 1 Sub-classes, 1 commands."""
 		if not hasattr(self, '_count'):
-			from .Count import Count
-			self._count = Count(self._core, self._cmd_group)
+			from .Count import CountCls
+			self._count = CountCls(self._core, self._cmd_group)
 		return self._count
 
 	@property
 	def maverage(self):
 		"""maverage commands group. 1 Sub-classes, 0 commands."""
 		if not hasattr(self, '_maverage'):
-			from .Maverage import Maverage
-			self._maverage = Maverage(self._core, self._cmd_group)
+			from .Maverage import MaverageCls
+			self._maverage = MaverageCls(self._core, self._cmd_group)
 		return self._maverage
 
-	def clone(self) -> 'IqAvg':
+	def clone(self) -> 'IqAvgCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = IqAvg(self._core, self._cmd_group.parent)
+		new_group = IqAvgCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
