@@ -4,7 +4,7 @@ from ........Internal import Conversions
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Vdevice:
+class VdeviceCls:
 	"""Vdevice commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
