@@ -3,8 +3,8 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Rdevice:
-	"""Rdevice commands group definition. 8 total commands, 1 Subgroups, 0 group commands"""
+class RdeviceCls:
+	"""Rdevice commands group definition. 11 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
 		self._core = core
@@ -14,14 +14,22 @@ class Rdevice:
 	def oscilloscope(self):
 		"""oscilloscope commands group. 7 Sub-classes, 0 commands."""
 		if not hasattr(self, '_oscilloscope'):
-			from .Oscilloscope import Oscilloscope
-			self._oscilloscope = Oscilloscope(self._core, self._cmd_group)
+			from .Oscilloscope import OscilloscopeCls
+			self._oscilloscope = OscilloscopeCls(self._core, self._cmd_group)
 		return self._oscilloscope
 
-	def clone(self) -> 'Rdevice':
+	@property
+	def pmeter(self):
+		"""pmeter commands group. 3 Sub-classes, 0 commands."""
+		if not hasattr(self, '_pmeter'):
+			from .Pmeter import PmeterCls
+			self._pmeter = PmeterCls(self._core, self._cmd_group)
+		return self._pmeter
+
+	def clone(self) -> 'RdeviceCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Rdevice(self._core, self._cmd_group.parent)
+		new_group = RdeviceCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
