@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Sync:
+class SyncCls:
 	"""Sync commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Sync:
 	def rlength(self):
 		"""rlength commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_rlength'):
-			from .Rlength import Rlength
-			self._rlength = Rlength(self._core, self._cmd_group)
+			from .Rlength import RlengthCls
+			self._rlength = RlengthCls(self._core, self._cmd_group)
 		return self._rlength
 
-	def clone(self) -> 'Sync':
+	def clone(self) -> 'SyncCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Sync(self._core, self._cmd_group.parent)
+		new_group = SyncCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
