@@ -3,7 +3,7 @@ from .....Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Trigger:
+class TriggerCls:
 	"""Trigger commands group definition. 4 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Trigger:
 	def sequence(self):
 		"""sequence commands group. 4 Sub-classes, 0 commands."""
 		if not hasattr(self, '_sequence'):
-			from .Sequence import Sequence
-			self._sequence = Sequence(self._core, self._cmd_group)
+			from .Sequence import SequenceCls
+			self._sequence = SequenceCls(self._core, self._cmd_group)
 		return self._sequence
 
-	def clone(self) -> 'Trigger':
+	def clone(self) -> 'TriggerCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Trigger(self._core, self._cmd_group.parent)
+		new_group = TriggerCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
